@@ -28,7 +28,7 @@ SettingsDialog::SettingsDialog(QWidget *parent)
  : QDialog(parent)
 {
     ui.setupUi(this);
-    setAttribute(Qt::WA_DeleteOnClose, TRUE);
+    setAttribute(Qt::WA_DeleteOnClose, true);
     QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
     ui.srSpinBox->setValue(settings.value("SRC/sample_rate",48000).toInt());
     ui.engineComboBox->setCurrentIndex(settings.value("SRC/engine", 0).toInt());
