@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2007 by Ilya Kotov                                      *
+ *   Copyright (C) 2007-2010 by Ilya Kotov                                 *
  *   forkotov02@hotmail.ru                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -20,12 +20,8 @@
 #ifndef SRCONVERTER_H
 #define SRCONVERTER_H
 
-#include <qmmp/effect.h>
-
-extern "C"
-{
 #include <samplerate.h>
-}
+#include <qmmp/effect.h>
 
 /**
     @author Ilya Kotov <forkotov02@hotmail.ru>
@@ -33,14 +29,12 @@ extern "C"
 
 class SRConverter : public Effect
 {
-    Q_OBJECT
 public:
-    SRConverter(QObject *parent = 0);
-
+    SRConverter();
     virtual ~SRConverter();
 
-    ulong process(char *in_data, const ulong size, char **out_data);
-    void configure(quint32 freq, int chan, int res);
+    void applyEffect(Buffer *b);
+    void configure(quint32 freq, int chan, Qmmp::AudioFormat format);
 
 private:
     void freeSRC();
@@ -49,9 +43,6 @@ private:
     quint32 m_overSamplingFs;
     int m_srcError;
     int m_converter_type;
-    bool m_isSrcAlloc;
-    float *m_srcIn, *m_srcOut;
-    short *m_wOut;
     quint32 m_freq;
 };
 
