@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2009 by Ilya Kotov                                 *
+ *   Copyright (C) 2008-2011 by Ilya Kotov                                 *
  *   forkotov02@hotmail.ru                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -162,19 +162,16 @@ qint64 MplayerEngine::totalTime()
 void MplayerEngine::seek(qint64 pos)
 {
     if (m_process->state() == QProcess::Running)
-        m_process->write(QString("seek %1 \n").arg(pos/1000 - m_currentTime).toLocal8Bit ());
+        m_process->write(QString("seek %1\n").arg(pos/1000 - m_currentTime).toLocal8Bit ());
 }
 
 void MplayerEngine::stop()
 {
-    if (m_process->state() == QProcess::Running)
-    {
-        m_process->write("quit\n");
-        m_process->waitForFinished(1500);
-    }
-    StateHandler::instance()->dispatch(Qmmp::Stopped);
     while(!m_sources.isEmpty())
         m_sources.dequeue()->deleteLater();
+    m_process->write("quit\n");
+    m_process->close();
+    StateHandler::instance()->dispatch(Qmmp::Stopped);
 }
 
 void MplayerEngine::pause()
@@ -242,6 +239,9 @@ void MplayerEngine::readStdOut()
 void MplayerEngine::startMplayerProcess()
 {
     initialize();
+    delete m_process;
+    m_process = new QProcess(this);
+    connect(m_process, SIGNAL(readyReadStandardOutput()), SLOT(readStdOut()));
     m_process->start ("mplayer", m_args);
     StateHandler::instance()->dispatch(Qmmp::Playing);
     FileInfo *info = MplayerInfo::createFileInfo(m_source->url());
@@ -249,4 +249,5 @@ void MplayerEngine::startMplayerProcess()
     delete info;
     m_source->deleteLater();
     m_source = 0;
+    m_currentTime = 0;
 }
