@@ -25,7 +25,7 @@
     </message>
     <message>
         <location filename="../halfactory.cpp" line="53"/>
-        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
+        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
         <translation>Yazan: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
     </message>
     <message>
@@ -37,12 +37,12 @@
 <context>
     <name>HalPlugin</name>
     <message>
-        <location filename="../halplugin.cpp" line="161"/>
+        <location filename="../halplugin.cpp" line="162"/>
         <source>Add CD &quot;%1&quot;</source>
         <translation>CD &quot;%1&quot; Ekle</translation>
     </message>
     <message>
-        <location filename="../halplugin.cpp" line="167"/>
+        <location filename="../halplugin.cpp" line="168"/>
         <source>Add Volume &quot;%1&quot;</source>
         <translation>&quot;%1&quot; Aygıtını Ekle</translation>
     </message>
