@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by Ilya Kotov                                      *
+ *   Copyright (C) 2008-2011 by Ilya Kotov                                 *
  *   forkotov02@hotmail.ru                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -19,9 +19,10 @@
  ***************************************************************************/
 
 #include <QSettings>
-
+#include <QFontDialog>
+#include <QMenu>
 #include <qmmp/qmmp.h>
-
+#include <qmmpui/templateeditor.h>
 #include "popupwidget.h"
 #include "settingsdialog.h"
 
@@ -44,12 +45,20 @@ SettingsDialog::SettingsDialog(QWidget *parent)
     settings.beginGroup("Notifier");
     ui.messageDelaySpinBox->setValue(settings.value("message_delay", 2000).toInt());
     uint pos = settings.value("message_pos", PopupWidget::BOTTOMLEFT).toUInt();
-    m_buttons.value(pos)->setChecked(TRUE);
-    ui.psiCheckBox->setChecked(settings.value("psi_notification", FALSE).toBool());
-    ui.songCheckBox->setChecked(settings.value("song_notification", TRUE).toBool());
-    ui.volumeCheckBox->setChecked(settings.value("volume_notification", TRUE).toBool());
+    m_buttons.value(pos)->setChecked(true);
+    ui.psiCheckBox->setChecked(settings.value("psi_notification", false).toBool());
+    ui.songCheckBox->setChecked(settings.value("song_notification", true).toBool());
+    ui.volumeCheckBox->setChecked(settings.value("volume_notification", true).toBool());
     ui.transparencySlider->setValue(100 - settings.value("opacity", 1.0).toDouble()*100);
+    QString fontname = settings.value ("font").toString();
+    ui.coverSizeSlider->setValue(settings.value ("cover_size", 64).toInt());
+    m_template = settings.value ("template", DEFAULT_TEMPLATE).toString();
     settings.endGroup();
+    QFont font;
+    if(!fontname.isEmpty())
+        font.fromString(fontname);
+    ui.fontLabel->setText (font.family () + " " + QString::number(font.pointSize ()));
+    ui.fontLabel->setFont(font);
 }
 
 
@@ -71,7 +80,30 @@ void SettingsDialog::accept()
     settings.setValue("psi_notification", ui.psiCheckBox->isChecked());
     settings.setValue("song_notification", ui.songCheckBox->isChecked());
     settings.setValue("volume_notification", ui.volumeCheckBox->isChecked());
-    settings.setValue ("opacity", 1.0 -  (double)ui.transparencySlider->value()/100);
+    settings.setValue("opacity", 1.0 -  (double)ui.transparencySlider->value()/100);
+    settings.setValue("font", ui.fontLabel->font().toString());
+    settings.setValue("cover_size", ui.coverSizeSlider->value());
+    settings.setValue("template", m_template);
     settings.endGroup();
     QDialog::accept();
 }
+
+void SettingsDialog::on_fontButton_pressed()
+{
+    bool ok;
+    QFont font = ui.fontLabel->font();
+    font = QFontDialog::getFont (&ok, font, this);
+    if (ok)
+    {
+        ui.fontLabel->setText (font.family () + " " + QString::number(font.pointSize ()));
+        ui.fontLabel->setFont(font);
+    }
+}
+
+void SettingsDialog::on_templateButton_pressed()
+{
+    QString t = TemplateEditor::getTemplate(this, tr("Notification Template"), m_template,
+                                            DEFAULT_TEMPLATE);
+    if(!t.isEmpty())
+        m_template = t;
+}
