@@ -37,7 +37,7 @@
 
 #define PROTOCOL_VER "1.2.1"
 #define CLIENT_ID "qmm"
-#define CLIENT_VER "0.3"
+#define CLIENT_VER "0.5"
 
 
 Scrobbler::Scrobbler(const QString &url,
@@ -135,7 +135,7 @@ void Scrobbler::setState(Qmmp::State state)
     case Qmmp::Stopped:
         if (!m_song.metaData().isEmpty()
             && ((m_time->elapsed ()/1000 > 240) || (m_time->elapsed ()/1000 > int(m_song.length()/2)))
-            && (m_time->elapsed ()/1000 > 60))
+            && (m_song.length() > MIN_SONG_LENGTH))
         {
             m_song.setTimeStamp(m_start_ts);
             m_songCache << m_song;
