@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by Ilya Kotov                                      *
+ *   Copyright (C) 2008-2009 by Ilya Kotov                                 *
  *   forkotov02@hotmail.ru                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -20,16 +20,16 @@
 #ifndef STATUSICON_H
 #define STATUSICON_H
 
-#include <QSystemTrayIcon>
 #include <QMap>
-
 #include <qmmpui/general.h>
 #include <qmmp/qmmp.h>
+#include "qmmptrayicon.h"
 
 class SoundCore;
 class MediaPlayer;
 class QEvent;
 
+
 /**
 	@author Ilya Kotov <forkotov02@hotmail.ru>
 */
@@ -48,9 +48,8 @@ private slots:
     void trayActivated(QSystemTrayIcon::ActivationReason);
 
 private:
-    QSystemTrayIcon *m_tray;
+    QmmpTrayIcon *m_tray;
     bool m_showMessage;
-    bool m_showTooltip;
     bool m_hideToTray;
     bool m_useStandardIcons;
     int m_messageDelay;
