@@ -61,11 +61,7 @@ DecoderCUE::~DecoderCUE()
 
 bool DecoderCUE::initialize()
 {
-    QString p = QUrl(m_path).path();
-    p.replace(QString(QUrl::toPercentEncoding("#")), "#");
-    p.replace(QString(QUrl::toPercentEncoding("?")), "?");
-    p.replace(QString(QUrl::toPercentEncoding("%")), "%");    
-    m_parser = new CUEParser(p);
+    m_parser = new CUEParser(m_path);
     if (m_parser->count() == 0)
     {
         qWarning("DecoderCUE: invalid cue file");
