@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2010 by Ilya Kotov                                 *
+ *   Copyright (C) 2008-2011 by Ilya Kotov                                 *
  *   forkotov02@hotmail.ru                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -43,10 +43,10 @@ const DecoderProperties DecoderCUEFactory::properties() const
     DecoderProperties properties;
     properties.name = tr("CUE Plugin");
     properties.shortName = "cue";
-    properties.filter = "*.cue";
+    properties.filters << "*.cue";
     properties.description = tr("CUE Files");
     //properties.contentType = "application/ogg;audio/x-vorbis+ogg";
-    properties.protocols = "cue";
+    properties.protocols << "cue";
     properties.hasAbout = true;
     properties.hasSettings = true;
     properties.noInput = true;
@@ -63,10 +63,20 @@ Decoder *DecoderCUEFactory::create(const QString &path, QIODevice *input)
 QList<FileInfo *> DecoderCUEFactory::createPlayList(const QString &fileName, bool useMetaData)
 {
     Q_UNUSED(useMetaData);
-    if(!QFile::exists(fileName))
-        return QList<FileInfo *>();
     CUEParser parser(fileName);
-    return parser.createPlayList();
+    if(fileName.contains("://"))
+    {
+        QList<FileInfo *> list;
+        int track = fileName.section("#", -1).toInt();
+        if (!parser.count() || track <= 0 || track > parser.count())
+            return list;
+        list = parser.createPlayList();
+        FileInfo *info = list.takeAt(track - 1);
+        qDeleteAll(list);
+        return QList<FileInfo *>() << info;
+    }
+    else
+        return parser.createPlayList();
 }
 
 MetaDataModel* DecoderCUEFactory::createMetaDataModel(const QString &path, QObject *parent)
@@ -84,7 +94,7 @@ void DecoderCUEFactory::showAbout(QWidget *parent)
 {
     QMessageBox::about (parent, tr("About CUE Audio Plugin"),
                         tr("Qmmp CUE Audio Plugin")+"\n"+
-                        tr("Writen by: Ilya Kotov <forkotov02@hotmail.ru>"));
+                        tr("Written by: Ilya Kotov <forkotov02@hotmail.ru>"));
 }
 
 QTranslator *DecoderCUEFactory::createTranslator(QObject *parent)
