@@ -58,8 +58,16 @@ SettingsDialog::SettingsDialog(QWidget *parent)
     ui.raCheckBox->setEnabled(avcodec_find_decoder(CODEC_ID_RA_288));
     ui.raCheckBox->setChecked(filters.contains("*.ra") && avcodec_find_decoder(CODEC_ID_RA_288));
     ui.shCheckBox->setChecked(filters.contains("*.shn") && avcodec_find_decoder(CODEC_ID_SHORTEN));
-    ui.ac3CheckBox->setEnabled(avcodec_find_decoder(CODEC_ID_AC3));
-    ui.ac3CheckBox->setChecked(filters.contains("*.ac3") && avcodec_find_decoder(CODEC_ID_AC3));
+    ui.ac3CheckBox->setEnabled(avcodec_find_decoder(CODEC_ID_EAC3));
+    ui.ac3CheckBox->setChecked(filters.contains("*.ac3") && avcodec_find_decoder(CODEC_ID_EAC3));
+    ui.dtsCheckBox->setEnabled(avcodec_find_decoder(CODEC_ID_DTS));
+    ui.dtsCheckBox->setChecked(filters.contains("*.dts") && avcodec_find_decoder(CODEC_ID_DTS));
+#if (LIBAVCODEC_VERSION_INT >= ((52<<16)+(22<<8)+0))
+    ui.mkaCheckBox->setEnabled(avcodec_find_decoder(CODEC_ID_TRUEHD));
+    ui.mkaCheckBox->setChecked(filters.contains("*.mka") && avcodec_find_decoder(CODEC_ID_TRUEHD));
+#else
+    ui.mkaCheckBox->setEnabled(false);
+#endif
 }
 
 SettingsDialog::~SettingsDialog()
@@ -87,6 +95,10 @@ void SettingsDialog::accept()
         filters << "*.shn";
     if (ui.ac3CheckBox->isChecked())
         filters << "*.ac3";
+    if (ui.dtsCheckBox->isChecked())
+        filters << "*.dts";
+    if (ui.mkaCheckBox->isChecked())
+        filters << "*.mka";
     QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
     settings.setValue("FFMPEG/filters", filters);
     QDialog::accept();
