@@ -25,11 +25,12 @@
 
 #include <FLAC/all.h>
 
-#define MAX_SUPPORTED_CHANNELS      2
-
-#define SAMPLES_PER_WRITE     512
+#define MAX_SUPPORTED_CHANNELS 2
+#define SAMPLES_PER_WRITE 512
 #define SAMPLE_BUFFER_SIZE ((FLAC__MAX_BLOCK_SIZE + SAMPLES_PER_WRITE) * MAX_SUPPORTED_CHANNELS * (32/8))
 
+class CUEParser;
+
 struct flac_data
 {
     //FLAC__SeekableStreamDecoder *decoder;
@@ -49,7 +50,7 @@ struct flac_data
     unsigned sample_rate;
     unsigned channels;
 
-    FLAC__uint64 last_decode_position;
+    FLAC__uint64 last_bytes;
 
     int ok; /* was this stream successfully opened? */
     //struct decoder_error error;
@@ -59,49 +60,44 @@ struct flac_data
 class DecoderFLAC : public Decoder
 {
 public:
-    DecoderFLAC(QObject *, DecoderFactory *, QIODevice *, Output *, const QString &path);
+    DecoderFLAC(const QString &path, QIODevice *i);
     virtual ~DecoderFLAC();
 
     // Standard Decoder API
     bool initialize();
     qint64 totalTime();
-    void seek(qint64);
-    void stop();
+    int bitrate();
+    qint64 read(char *data, qint64 maxSize);
+    void seek(qint64 time);
+    const QString nextURL();
+    void next();
 
     struct flac_data *data()
     {
         return m_data;
     }
 
-
 private:
-    // thread run function
-    void run();
-    struct flac_data *m_data;
+
     // helper functions
-    void flush(bool = FALSE);
     void deinit();
-
-    bool inited, user_stop;
-    int stat;
-
-    // output buffer
-    char *output_buf;
-    ulong output_bytes, output_at;
+    uint findID3v2(char *data, ulong size); //retuns ID3v2 tag size
 
     // FLAC Decoder
-    //FLAC__SeekableStreamDecoder *m_flacDecoder;
     FLAC__StreamDecoder *m_flacDecoder;
 
-    unsigned int bks;
-    bool done, m_finish;
-    long len, freq, bitrate;
-    int chan;
-    unsigned long output_size;
-    double m_totalTime, seekTime;
-    QString m_path;
+    struct flac_data *m_data;
+    qint64 m_totalTime;
+    qint64 length_in_bytes;
+    qint64 m_totalBytes;
     qint64 m_offset;
     qint64 m_length;
+    QString m_path;
+    CUEParser *m_parser;
+    int m_track;
+    char *m_buf; //buffer for remainig data
+    qint64 m_buf_size;
+    qint64 m_sz; //sample size
 };
 
 
