@@ -14,60 +14,60 @@
         <translation>Soubory FLAC</translation>
     </message>
     <message>
-        <location filename="../decoderflacfactory.cpp" line="151"/>
+        <location filename="../decoderflacfactory.cpp" line="172"/>
         <source>About FLAC Audio Plugin</source>
         <translation>O modulu FLAC</translation>
     </message>
     <message>
-        <location filename="../decoderflacfactory.cpp" line="152"/>
+        <location filename="../decoderflacfactory.cpp" line="173"/>
         <source>Qmmp FLAC Audio Plugin</source>
         <translation>Vstupní modul Qmmp FLAC</translation>
     </message>
     <message>
-        <location filename="../decoderflacfactory.cpp" line="153"/>
-        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
+        <location filename="../decoderflacfactory.cpp" line="174"/>
+        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
         <translation>Autor: Ilja Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
     </message>
 </context>
 <context>
     <name>FLACMetaDataModel</name>
     <message>
-        <location filename="../flacmetadatamodel.cpp" line="81"/>
+        <location filename="../flacmetadatamodel.cpp" line="82"/>
         <source>Length</source>
         <translation>Délka</translation>
     </message>
     <message>
-        <location filename="../flacmetadatamodel.cpp" line="82"/>
+        <location filename="../flacmetadatamodel.cpp" line="83"/>
         <source>Sample rate</source>
         <translation>Vzorkovací frekvence</translation>
     </message>
     <message>
-        <location filename="../flacmetadatamodel.cpp" line="82"/>
+        <location filename="../flacmetadatamodel.cpp" line="83"/>
         <source>Hz</source>
         <translation>Hz</translation>
     </message>
     <message>
-        <location filename="../flacmetadatamodel.cpp" line="83"/>
+        <location filename="../flacmetadatamodel.cpp" line="84"/>
         <source>Channels</source>
         <translation>Počet kanálů</translation>
     </message>
     <message>
-        <location filename="../flacmetadatamodel.cpp" line="84"/>
+        <location filename="../flacmetadatamodel.cpp" line="85"/>
         <source>Bitrate</source>
         <translation>Datový tok</translation>
     </message>
     <message>
-        <location filename="../flacmetadatamodel.cpp" line="84"/>
+        <location filename="../flacmetadatamodel.cpp" line="85"/>
         <source>kbps</source>
         <translation>kbps</translation>
     </message>
     <message>
-        <location filename="../flacmetadatamodel.cpp" line="86"/>
+        <location filename="../flacmetadatamodel.cpp" line="87"/>
         <source>File size</source>
         <translation>Velikost souboru</translation>
     </message>
     <message>
-        <location filename="../flacmetadatamodel.cpp" line="86"/>
+        <location filename="../flacmetadatamodel.cpp" line="87"/>
         <source>KB</source>
         <translation>KiB</translation>
     </message>
