@@ -28,9 +28,7 @@
 #include <qmmp/decoder.h>
 #include <qmmp/output.h>
 #include <qmmp/decoderfactory.h>
-
-
-
+#include <qmmp/metadatamodel.h>
 
 class DecoderMADFactory : public QObject,
                           DecoderFactory
@@ -42,10 +40,9 @@ public:
     bool supports(const QString &source) const;
     bool canDecode(QIODevice *input) const;
     const DecoderProperties properties() const;
-    Decoder *create(QObject *, QIODevice *, Output *, const QString &);
-    //FileInfo *createFileInfo(const QString &source);
+    Decoder *create(const QString &path, QIODevice *input);
     QList<FileInfo *> createPlayList(const QString &fileName, bool useMetaData);
-    QObject* showDetails(QWidget *parent, const QString &path);
+    MetaDataModel* createMetaDataModel(const QString &path, QObject *parent = 0);
     void showSettings(QWidget *parent);
     void showAbout(QWidget *parent);
     QTranslator *createTranslator(QObject *parent);
