@@ -261,7 +261,7 @@ TimeValDifference(struct timeval *start, struct timeval *end)
    trying to trace mutexes it's more important to know *who* called us than just that
    we were called.  This uses from pre-processor trickery so that the fprintf is actually
    placed in the function making the getDriver call.  Thus, the __FUNCTION__ and __LINE__
-   macros will actually reference our caller, rather than getDriver.  The reason the 
+   macros will actually reference our caller, rather than getDriver.  The reason the
    fprintf call is passes as a parameter is because this macro has to still return a
    jack_driver_t* and we want to log both before *and* after the getDriver call for
    easier detection of blocked calls.
@@ -792,7 +792,7 @@ JACK_callback(nframes_t nframes, void *arg)
           /* the ringbuffer is designed such that only one thread should ever access each pointer.
              since calling read_advance here will be touching the read pointer which is also accessed
              by JACK_Read, we need to lock the mutex first for safety */
-	        jack_driver_t *d = tryGetDriver(drv->deviceID);
+            jack_driver_t *d = tryGetDriver(drv->deviceID);
           if( d )
           {
             /* double check the write space after we've gained the lock, just
@@ -803,7 +803,7 @@ JACK_callback(nframes_t nframes, void *arg)
              ERR("buffer overrun of %ld bytes\n", jack_bytes - write_space);
              jack_ringbuffer_read_advance(drv->pRecPtr, jack_bytes - write_space);
             }
-	          releaseDriver(drv);
+              releaseDriver(drv);
           }
         }
 
@@ -917,10 +917,10 @@ JACK_shutdown(void *arg)
 
   TRACE("trying to reconnect right now\n");
   /* lets see if we can't reestablish the connection */
-  if(JACK_OpenDevice(drv) != ERR_SUCCESS)
+  /*if(JACK_OpenDevice(drv) != ERR_SUCCESS)
   {
     ERR("unable to reconnect with jack\n");
-  }
+  }*/
 
   releaseDriver(drv);
 }
@@ -980,11 +980,11 @@ JACK_OpenDevice(jack_driver_t * drv)
 
   /* try to become a client of the JACK server */
   TRACE("client name '%s'\n", our_client_name);
-  if((drv->client = jack_client_new(our_client_name)) == 0)
+  if((drv->client = jack_client_open(our_client_name, JackNullOption | JackNoStartServer, NULL)) == 0)
   {
     /* try once more */
     TRACE("trying once more to jack_client_new");
-    if((drv->client = jack_client_new(our_client_name)) == 0)
+    if((drv->client = jack_client_open(our_client_name, JackNullOption | JackNoStartServer, NULL)) == 0)
     {
       ERR("jack server not running?\n");
       free(our_client_name);
@@ -1423,7 +1423,7 @@ JACK_Reset(int deviceID)
  * deviceID is set to the opened device
  * if client is non-zero and in_use is FALSE then just set in_use to TRUE
  *
- * return value is zero upon success, non-zero upon failure 
+ * return value is zero upon success, non-zero upon failure
  *
  * if ERR_RATE_MISMATCH (*rate) will be updated with the jack servers rate
  */
@@ -1521,7 +1521,7 @@ JACK_OpenEx(int *deviceID, unsigned int bits_per_channel,
   drv->jack_output_port_flags = jack_port_flags | JackPortIsInput;      /* port must be input(ie we can put data into it), so mask this in */
   drv->jack_input_port_flags = jack_port_flags | JackPortIsOutput;      /* port must be output(ie we can get data from it), so mask this in */
 
-  /* check that we have the correct number of port names 
+  /* check that we have the correct number of port names
      FIXME?: not sure how we should handle output ports vs input ports....
    */
   if((jack_port_name_count > 1)
@@ -1655,16 +1655,18 @@ JACK_OpenEx(int *deviceID, unsigned int bits_per_channel,
   /* FIXME: maybe we should keep different latency values for input vs output? */
   if(drv->num_output_channels > 0)
   {
-    periods = jack_port_get_total_latency(drv->client,
-                                          drv->output_port[0]) / periodSize;
+    jack_latency_range_t range;
+    jack_port_get_latency_range(drv->output_port[0], JackPlaybackLatency, &range);
+    periods = range.max / periodSize;
     drv->latencyMS = periodSize * periods * 1000 / (drv->jack_sample_rate *
                                                     (drv->bits_per_channel / 8 *
                                                      drv->num_output_channels));
   }
   else if(drv->num_input_channels > 0)
   {
-    periods = jack_port_get_total_latency(drv->client,
-                                          drv->input_port[0]) / periodSize;
+    jack_latency_range_t range;
+    jack_port_get_latency_range(drv->output_port[0], JackPlaybackLatency, &range);
+    periods = range.max / periodSize;
     drv->latencyMS =
       periodSize * periods * 1000 / (drv->jack_sample_rate *
                                      (drv->bits_per_channel / 8 *
@@ -1759,7 +1761,7 @@ JACK_Write(int deviceID, unsigned char *data, unsigned long bytes)
   TRACE("frames free == %ld, bytes = %lu\n", frames_free, bytes);
 
   TRACE("state = '%s'\n", DEBUGSTATE(drv->state));
-  /* if we are currently STOPPED we should start playing now... 
+  /* if we are currently STOPPED we should start playing now...
      do this before the check for bytes == 0 since some clients like
      to write 0 bytes the first time out */
   if(drv->state == STOPPED)
@@ -2542,8 +2544,12 @@ JACK_GetJackOutputLatency(int deviceID)
   jack_driver_t *drv = getDriver(deviceID);
   long return_val = 0;
 
-  if(drv->client && drv->num_output_channels)
-    return_val = jack_port_get_total_latency(drv->client, drv->output_port[0]);
+  if(drv->client && drv->num_input_channels)
+  {
+    jack_latency_range_t range;
+    jack_port_get_latency_range(drv->output_port[0], JackCaptureLatency, &range);
+    return_val = range.max;
+  }
 
   TRACE("got latency of %ld frames\n", return_val);
 
@@ -2559,8 +2565,11 @@ JACK_GetJackInputLatency(int deviceID)
   long return_val = 0;
 
   if(drv->client && drv->num_input_channels)
-    return_val = jack_port_get_total_latency(drv->client, drv->input_port[0]);
-
+  {
+    jack_latency_range_t range;
+    jack_port_get_latency_range(drv->output_port[0], JackPlaybackLatency, &range);
+    return_val = range.max;
+  }
   TRACE("got latency of %ld frames\n", return_val);
 
   releaseDriver(drv);
