@@ -20,13 +20,13 @@
     </message>
     <message>
         <location filename="../outputwaveoutfactory.cpp" line="56"/>
-        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
+        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
         <translation>制作: Илья Котов (Ilya Kotov) &lt;forkotov02@hotmail.ru&gt;</translation>
     </message>
     <message>
         <location filename="../outputwaveoutfactory.cpp" line="57"/>
         <source>Based on aacDECdrop player</source>
-        <translation>aacDECdrop プレイヤから流用</translation>
+        <translation>aacDECdrop プレイヤを基に作成</translation>
     </message>
 </context>
 </TS>
