@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2009 by Ilya Kotov                                      *
+ *   Copyright (C) 2009-2011 by Ilya Kotov                                 *
  *   forkotov02@hotmail.ru                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -18,13 +18,14 @@
  *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
  ***************************************************************************/
 
-#include "streamreader.h"
+#include "mmsstreamreader.h"
 #include "mmsinputsource.h"
 
 MMSInputSource::MMSInputSource(const QString &url, QObject *parent) : InputSource(url,parent)
 {
-    m_reader = new StreamReader(url, this);
-    connect(m_reader, SIGNAL(readyRead()),SLOT(open()));
+    m_reader = new MMSStreamReader(url, this);
+    connect(m_reader, SIGNAL(ready()),SIGNAL(ready()));
+    connect(m_reader, SIGNAL(error()),SIGNAL(error()));
 }
 
 QIODevice *MMSInputSource::ioDevice()
@@ -47,9 +48,3 @@ QString  MMSInputSource::contentType() const
 {
     return "audio/x-ms-wma";
 }
-
-void MMSInputSource::open()
-{
-    m_reader->open(QIODevice::ReadOnly);
-    emit(ready(this));
-}
