@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2009 by Ilya Kotov                                      *
+ *   Copyright (C) 2009-2011 by Ilya Kotov                                 *
  *   forkotov02@hotmail.ru                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -23,7 +23,7 @@
 
 #include <qmmp/inputsource.h>
 
-class StreamReader;
+class MMSStreamReader;
 
 /**
     @author Ilya Kotov <forkotov02@hotmail.ru>
@@ -39,12 +39,9 @@ public:
     bool isReady();
     QString contentType() const;
 
-private slots:
-    void open();
-
 private:
-    StreamReader *m_reader;
+    MMSStreamReader *m_reader;
 
 };
 
-#endif // HTTPINPUTSOURCE_H
+#endif // MMSINPUTSOURCE_H
