@@ -23,6 +23,7 @@
 #include <QPluginLoader>
 #include <QApplication>
 #include "enginefactory.h"
+#include "qmmpaudioengine.h"
 #include "qmmp.h"
 #include "abstractengine.h"
 
@@ -42,6 +43,7 @@ QWaitCondition *AbstractEngine::cond()
 
 // static methods
 QList<EngineFactory*> *AbstractEngine::m_factories = 0;
+QList<EngineFactory*> *AbstractEngine::m_disabledFactories = 0;
 QStringList AbstractEngine::m_files;
 
 void AbstractEngine::checkFactories()
@@ -49,8 +51,10 @@ void AbstractEngine::checkFactories()
     if (!m_factories)
     {
         QSettings settings (Qmmp::configFile(), QSettings::IniFormat);
+        QStringList disabledNames  = settings.value("Engine/disabled_plugins").toStringList ();
         m_files.clear();
         m_factories = new QList<EngineFactory *>;
+        m_disabledFactories = new QList<EngineFactory *>;
 
         QDir pluginsDir (Qmmp::pluginsPath());
         pluginsDir.cd("Engines");
@@ -71,6 +75,8 @@ void AbstractEngine::checkFactories()
                 m_factories->append(factory);
                 m_files << pluginsDir.absoluteFilePath(fileName);
                 qApp->installTranslator(factory->createTranslator(qApp));
+                if(disabledNames.contains(factory->properties().shortName))
+                    m_disabledFactories->append(factory);
             }
         }
         //remove physically deleted plugins from disabled list
@@ -79,16 +85,44 @@ void AbstractEngine::checkFactories()
         {
             names.append(factory->properties().shortName);
         }
-        QStringList disabledList  = settings.value("Engine/disabled_plugins").toStringList ();
-        foreach (QString name, disabledList)
+        foreach (QString name, disabledNames)
         {
             if (!names.contains(name))
-                disabledList.removeAll(name);
+                disabledNames.removeAll(name);
         }
-        settings.setValue("Engine/disabled_plugins",disabledList);
+        settings.setValue("Engine/disabled_plugins", disabledNames);
     }
 }
 
+AbstractEngine *AbstractEngine::create(InputSource *s, QObject *parent)
+{
+    AbstractEngine *engine = new QmmpAudioEngine(parent); //internal engine
+    if(!engine->enqueue(s))
+    {
+        engine->deleteLater();
+        engine = 0;
+    }
+    else
+        return engine;
+
+
+    checkFactories();
+    foreach(EngineFactory *f, *m_factories)
+    {
+        if(!isEnabled(f))
+            continue;
+        engine = f->create(parent); //engine plugin
+        if(!engine->enqueue(s))
+        {
+            engine->deleteLater();
+            engine = 0;
+        }
+        else
+            break;
+    }
+    return engine;
+}
+
 QList<EngineFactory*> *AbstractEngine::factories()
 {
     checkFactories();
@@ -112,29 +146,28 @@ void AbstractEngine::setEnabled(EngineFactory* factory, bool enable)
     if (!m_factories->contains(factory))
         return;
 
-    QString name = factory->properties().shortName;
-    QSettings settings (Qmmp::configFile(), QSettings::IniFormat );
-    QStringList disabledList = settings.value("Engine/disabled_plugins").toStringList();
+    if(enable == isEnabled(factory))
+        return;
 
-    if (enable)
-        disabledList.removeAll(name);
+    if(enable)
+        m_disabledFactories->removeAll(factory);
     else
+        m_disabledFactories->append(factory);
+
+    QStringList disabledNames;
+    foreach(EngineFactory *f, *m_disabledFactories)
     {
-        if (!disabledList.contains(name))
-            disabledList << name;
+        disabledNames << f->properties().shortName;
     }
-    settings.setValue("Engine/disabled_plugins", disabledList);
+    disabledNames.removeDuplicates();
+    QSettings settings (Qmmp::configFile(), QSettings::IniFormat);
+    settings.setValue("Engine/disabled_plugins", disabledNames);
 }
 
 bool AbstractEngine::isEnabled(EngineFactory* factory)
 {
     checkFactories();
-    if (!m_factories->contains(factory))
-        return false;
-    QString name = factory->properties().shortName;
-    QSettings settings ( Qmmp::configFile(), QSettings::IniFormat );
-    QStringList disabledList = settings.value("Engine/disabled_plugins").toStringList();
-    return !disabledList.contains(name);
+    return !m_disabledFactories->contains(factory);
 }
 
 QStringList AbstractEngine::files()
@@ -143,3 +176,15 @@ QStringList AbstractEngine::files()
     return m_files;
 }
 
+QStringList AbstractEngine::protocols()
+{
+    QStringList protocolsList;
+    foreach(EngineFactory *f, *m_factories)
+    {
+        if(isEnabled(f))
+            protocolsList << f->properties().protocols;
+    }
+    protocolsList.removeDuplicates();
+    return protocolsList;
+}
+
