@@ -49,12 +49,11 @@ public:
     /*!
      * Adds data for visualization.
      * Subclass should reimplement this function.
-     * @param b Buffer object pointer.
-     * @param freq Samplerate.
-     * @param chan Number of channels
-     * @param bits Bits per sample.
+     * @param data Audio data.
+     * @param size Size of audio data.
+     * @param chan Number of channels.
      */
-    virtual void add(Buffer *b, unsigned long freq, int chan, int bits) = 0;
+    virtual void add(unsigned char *data, qint64 size, int chan) = 0;
     /*!
      * Resets visual plugin buffers and widgets.
      * Subclass should reimplement this function.
@@ -77,7 +76,7 @@ public:
      * @param factory Visual plugin factory.
      * @param enable Plugin enable state (\b true - enable, \b false - disable)
      */
-    static void setEnabled(VisualFactory* factory, bool enable = TRUE);
+    static void setEnabled(VisualFactory* factory, bool enable = true);
     /*!
      * Returns \b true if visual plugin is enabled, otherwise returns \b false
      * @param factory Effect plugin factory.
