@@ -23,6 +23,8 @@
 class QObject;
 class QTranslator;
 class FileDialog;
+class QWidget;
+class QString;
 
 /*! @brief Helper class to store file dialog plugin properies.
  */
@@ -34,7 +36,7 @@ public:
      */
     FileDialogProperties()
     {
-        hasAbout = FALSE;
+        hasAbout = false;
     }
     bool hasAbout;      /*!< Should be \b true if the file dialog plugin has about dialog, otherwise should be
                          * \b false */
