@@ -114,32 +114,18 @@ void MediaPlayer::stop()
 
 void MediaPlayer::next()
 {
-    if (!m_pl_manager->currentPlayList()->next())
-    {
-        stop();
-        return;
-    }
-    if (m_core->state() != Qmmp::Stopped)
-    {
-        stop();
+    bool playNext = m_core->state() != Qmmp::Stopped;
+    stop();
+    if (m_pl_manager->currentPlayList()->next() && playNext)
         play();
-    }
 }
 
 void MediaPlayer::previous()
 {
-    if (!m_pl_manager->currentPlayList()->previous())
-    {
-        stop();
-        return;
-    }
-
-    if (m_core->state() != Qmmp::Stopped)
-    {
-        if (m_core->state() == Qmmp::Paused)
-            stop();
+    bool playPrevious = m_core->state() != Qmmp::Stopped;
+    stop();
+    if (m_pl_manager->currentPlayList()->previous() && playPrevious)
         play();
-    }
 }
 
 void MediaPlayer::setRepeatable(bool r)
