@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright(C) 2006-2010 by Ilya Kotov                                  *
+ *   Copyright(C) 2006-2011 by Ilya Kotov                                  *
  *   forkotov02@hotmail.ru                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -73,21 +73,20 @@ PlayListModel::PlayListModel(const QString &name, QObject *parent)
     m_total_length = 0;
     m_current = 0;
     is_repeatable_list = false;
+    m_stop_item = 0;
     m_play_state = new NormalPlayState(this);
+    m_loader = new FileLoader(this);
+    connect(m_loader, SIGNAL(newPlayListItem(PlayListItem*)),
+            SLOT(add(PlayListItem*)), Qt::QueuedConnection);
+    connect(m_loader, SIGNAL(finished()), SLOT(preparePlayState()));
+    connect(m_loader, SIGNAL(finished()), SIGNAL(loaderFinished()));
 }
 
 PlayListModel::~PlayListModel()
 {
     clear();
     delete m_play_state;
-    foreach(GuardedFileLoader l,m_running_loaders)
-    {
-        if (!l.isNull())
-        {
-            l->finish();
-            l->wait();
-        }
-    }
+    m_loader->finish();
 }
 
 QString PlayListModel::name() const
@@ -113,8 +112,7 @@ void PlayListModel::add(PlayListItem *item)
     m_items << item;
     m_current = m_items.indexOf(m_currentItem);
 
-    if (m_items.size() == 1)
-        emit firstAdded();    
+    emit itemAdded(item);
     emit listChanged();
 }
 
@@ -125,16 +123,37 @@ void PlayListModel::add(QList <PlayListItem *> items)
     if (m_items.isEmpty())
         m_currentItem = items.at(0);
 
-    foreach(PlayListItem *item, items)
-        m_total_length += item->length();
     m_items << items;
-
-    if (m_items.size() == items.size())
-        emit firstAdded();
     m_current = m_items.indexOf(m_currentItem);
+    foreach(PlayListItem *item, items)
+    {
+        m_total_length += item->length();
+        emit itemAdded(item);
+    }
     emit listChanged();
 }
 
+void PlayListModel::add(const QString &path)
+{
+    QFileInfo f_info(path);
+    if (f_info.isDir())
+        m_loader->loadDirectory(path);
+    else
+    {
+        m_loader->loadFile(path);
+        loadPlaylist(path);
+    }
+
+}
+
+void PlayListModel::add(const QStringList &paths)
+{
+    foreach(QString str, paths)
+    {
+        add(str);
+    }
+}
+
 int PlayListModel::count()
 {
     return m_items.size();
@@ -147,11 +166,16 @@ PlayListItem* PlayListModel::currentItem()
 
 PlayListItem* PlayListModel::nextItem()
 {
-    if(isShuffle() || m_items.isEmpty() || !isEmptyQueue())
+    if(m_items.isEmpty() || !m_play_state)
         return 0;
-    if(m_current < m_items.size() - 1)
-        return m_items.at(m_current + 1);
-    return 0;
+    if(m_stop_item && m_stop_item == currentItem())
+        return 0;
+    if(!isEmptyQueue())
+        return m_queued_songs.at(0);
+    int index = m_play_state->nextIndex();
+    if(index < 0 || (index + 1 > m_items.count()))
+        return 0;
+    return m_items.at(index);
 }
 
 PlayListItem* PlayListModel::item(int row) const
@@ -175,40 +199,44 @@ bool PlayListModel::setCurrent(int c)
     return true;
 }
 
+bool PlayListModel::setCurrent(PlayListItem *item)
+{
+    if(!m_items.contains(item))
+        return false;
+    return setCurrent(m_items.indexOf(item));
+}
+
 bool PlayListModel::next()
 {
+    if(m_stop_item == currentItem())
+    {
+        m_stop_item = 0;
+        emit listChanged();
+        return false;
+    }
     if (!isEmptyQueue())
     {
         setCurrentToQueued();
         return true;
     }
 
-    if (isFileLoaderRunning())
+    if(m_loader->isRunning())
         m_play_state->prepare();
     return m_play_state->next();
 }
 
 bool PlayListModel::previous()
 {
-    if (isFileLoaderRunning())
+    if (m_loader->isRunning())
         m_play_state->prepare();
     return m_play_state->previous();
 }
 
 void PlayListModel::clear()
 {
-    foreach(GuardedFileLoader l,m_running_loaders)
-    {
-        if (!l.isNull())
-        {
-            l->finish();
-            l->wait();
-        }
-    }
-
-    m_running_loaders.clear();
-
+    m_loader->finish();
     m_current = 0;
+    m_stop_item = 0;
     while (!m_items.isEmpty())
     {
         PlayListItem* mf = m_items.takeFirst();
@@ -236,7 +264,7 @@ void PlayListModel::clearSelection()
     emit listChanged();
 }
 
-QList <QString> PlayListModel::getTitles(int b,int l)
+QStringList PlayListModel::getTitles(int b,int l)
 {
     QList <QString> m_titles;
     for (int i = b;(i < b + l) &&(i < m_items.size()); ++i)
@@ -244,7 +272,7 @@ QList <QString> PlayListModel::getTitles(int b,int l)
     return m_titles;
 }
 
-QList <QString> PlayListModel::getTimes(int b,int l)
+QStringList PlayListModel::getTimes(int b,int l)
 {
     QList <QString> m_times;
     int d = 0;
@@ -257,6 +285,8 @@ QList <QString> PlayListModel::getTimes(int b,int l)
         else
             str += QString("%1").arg(d%3600/60);
         str += QString(":%1").arg(d%60, 2, 10, QChar('0'));
+        if(!d)
+            str.clear();
         m_times << str;
         str.clear();
     }
@@ -302,6 +332,8 @@ void PlayListModel::removeAt (int i)
     if ((i < count()) && (i >= 0))
     {
         PlayListItem* f = m_items.takeAt(i);
+        if(m_stop_item == f)
+            m_stop_item = 0;
         m_total_length -= f->length();
         if (m_total_length < 0)
             m_total_length = qMin(0, m_total_length);
@@ -342,6 +374,8 @@ void PlayListModel::removeSelection(bool inverted)
         if (m_items.at(i)->isSelected() ^ inverted)
         {
             PlayListItem* f = m_items.takeAt(i);
+            if(f == m_stop_item)
+                m_stop_item = 0;
             m_total_length -= f->length();
             if (m_total_length < 0)
                 m_total_length = 0;
@@ -390,13 +424,13 @@ void PlayListModel::selectAll()
     emit listChanged();
 }
 
-void PlayListModel::showDetails()
+void PlayListModel::showDetails(QWidget *parent)
 {
     for (int i = 0; i<m_items.size(); ++i)
     {
         if (m_items.at(i)->isSelected())
         {
-            QDialog *d = new DetailsDialog(m_items.at(i)); //TODO set parent widget
+            QDialog *d = new DetailsDialog(m_items.at(i), parent);
             TagUpdater *updater = new TagUpdater(d, m_items.at(i));
             m_editing_items.append(m_items.at(i));
             connect(updater, SIGNAL(destroyed(QObject *)),SIGNAL(listChanged()));
@@ -406,92 +440,6 @@ void PlayListModel::showDetails()
     }
 }
 
-void PlayListModel::addFile(const QString& path)
-{
-    if (path.isEmpty())
-        return;
-    QList <FileInfo *> playList =
-            MetaDataManager::instance()->createPlayList(path, PlaylistSettings::instance()->useMetadata());
-    foreach(FileInfo *info, playList)
-        add(new PlayListItem(info));
-
-    m_play_state->prepare();
-}
-
-FileLoader * PlayListModel::createFileLoader()
-{
-    FileLoader* f_loader = new FileLoader(this);
-// f_loader->setStackSize(20 * 1024 * 1024);
-    m_running_loaders << f_loader;
-    connect(f_loader,SIGNAL(newPlayListItem(PlayListItem*)),SLOT(add(PlayListItem*)),Qt::QueuedConnection);
-    connect(f_loader,SIGNAL(finished()),this,SLOT(preparePlayState()));
-    connect(f_loader,SIGNAL(finished()),f_loader,SLOT(deleteLater()));
-    return f_loader;
-}
-
-void PlayListModel::addFiles(const QStringList &files)
-{
-    FileLoader* f_loader = createFileLoader();
-    f_loader->setFilesToLoad(files);
-    f_loader->start(QThread::IdlePriority);
-}
-
-void PlayListModel::addDirectory(const QString& s)
-{
-    FileLoader* f_loader = createFileLoader();
-    f_loader->setDirectoryToLoad(s);
-    f_loader->start(QThread::IdlePriority);
-}
-
-void PlayListModel::addFileList(const QStringList &l)
-{
-//    qWarning("void// PlayListModel::addFileList(const QStringList &l)");
-    foreach(QString str,l)
-    {
-        QFileInfo f_info(str);
-        if (f_info.exists() || str.contains("://"))
-        {
-            if (f_info.isDir())
-                addDirectory(str);
-            else
-            {
-                addFile(str);
-                loadPlaylist(str);
-            }
-        }
-        // Do processing the rest of events to avoid GUI freezing
-        QApplication::processEvents(QEventLoop::AllEvents,10);
-    }
-}
-
-bool PlayListModel::setFileList(const QStringList & l)
-{
-    bool model_cleared = false;
-    foreach(QString str,l)
-    {
-        QFileInfo f_info(str);
-        if (f_info.exists() || str.contains("://"))
-        {
-            if (!model_cleared)
-            {
-                clear();
-                model_cleared = true;
-            }
-            if (f_info.isDir())
-                addDirectory(str);
-            else
-            {
-                addFile(str);
-                loadPlaylist(str);
-            }
-        }
-        // Do processing the rest of events to avoid GUI freezing
-        QApplication::processEvents(QEventLoop::AllEvents,10);
-    }
-
-    return model_cleared;
-}
-
 int PlayListModel::firstSelectedUpper(int row)
 {
     for (int i = row - 1;i >= 0;i--)
@@ -620,9 +568,9 @@ void PlayListModel::addToQueue()
 void PlayListModel::setQueued(PlayListItem* file)
 {
     if (isQueued(file))
-        m_queued_songs.removeAt(m_queued_songs.indexOf(file));
+        m_queued_songs.removeAll(file);
     else
-        m_queued_songs.append(file);
+        m_queued_songs.enqueue(file);
     emit listChanged();
 }
 
@@ -633,8 +581,7 @@ bool PlayListModel::isQueued(PlayListItem* f) const
 
 void PlayListModel::setCurrentToQueued()
 {
-    setCurrent(row(m_queued_songs.at(0)));
-    m_queued_songs.pop_front();
+    setCurrent(row(m_queued_songs.dequeue()));
 }
 
 bool PlayListModel::isEmptyQueue() const
@@ -642,6 +589,21 @@ bool PlayListModel::isEmptyQueue() const
     return m_queued_songs.isEmpty();
 }
 
+int PlayListModel::queuedIndex(PlayListItem* item) const
+{
+    return m_queued_songs.indexOf(item);
+}
+
+int PlayListModel::queueSize() const
+{
+    return m_queued_songs.size();
+}
+
+bool PlayListModel::isStopAfter(PlayListItem* item) const
+{
+    return m_stop_item == item;
+}
+
 void PlayListModel::randomizeList()
 {
     for (int i = 0;i < m_items.size();i++)
@@ -668,32 +630,32 @@ void PlayListModel::reverseList()
 //by title
 static bool _titleLessComparator(PlayListItem* s1,PlayListItem* s2)
 {
-    return QString::localeAwareCompare (s1->title(), s2->title()) < 0;
+    return QString::localeAwareCompare (s1->value(Qmmp::TITLE), s2->value(Qmmp::TITLE)) < 0;
 }
 
 static bool _titleGreaterComparator(PlayListItem* s1,PlayListItem* s2)
 {
-    return QString::localeAwareCompare (s1->title(), s2->title()) > 0;
+    return QString::localeAwareCompare (s1->value(Qmmp::TITLE), s2->value(Qmmp::TITLE)) > 0;
 }
 //by album
 static bool _albumLessComparator(PlayListItem* s1,PlayListItem* s2)
 {
-    return QString::localeAwareCompare (s1->album(), s2->album()) < 0;
+    return QString::localeAwareCompare (s1->value(Qmmp::ALBUM), s2->value(Qmmp::ALBUM)) < 0;
 }
 
 static bool _albumGreaterComparator(PlayListItem* s1,PlayListItem* s2)
 {
-    return QString::localeAwareCompare (s1->album(), s2->album()) > 0;
+    return QString::localeAwareCompare (s1->value(Qmmp::ALBUM), s2->value(Qmmp::ALBUM)) > 0;
 }
 //by artist
 static bool _artistLessComparator(PlayListItem* s1,PlayListItem* s2)
 {
-    return QString::localeAwareCompare (s1->artist(), s2->artist()) < 0;
+    return QString::localeAwareCompare (s1->value(Qmmp::ALBUM), s2->value(Qmmp::ALBUM)) < 0;
 }
 
 static bool _artistGreaterComparator(PlayListItem* s1,PlayListItem* s2)
 {
-    return QString::localeAwareCompare (s1->artist(), s2->artist()) > 0;
+    return QString::localeAwareCompare (s1->value(Qmmp::ARTIST), s2->value(Qmmp::ARTIST)) > 0;
 }
 //by path
 static bool _pathAndFilenameLessComparator(PlayListItem* s1,PlayListItem* s2)
@@ -722,22 +684,22 @@ static bool _filenameGreaterComparator(PlayListItem* s1,PlayListItem* s2)
 //by date
 static bool _dateLessComparator(PlayListItem* s1,PlayListItem* s2)
 {
-    return s1->year().toInt() < s2->year().toInt();
+    return s1->value(Qmmp::YEAR).toInt() < s2->value(Qmmp::YEAR).toInt();
 }
 
 static bool _dateGreaterComparator(PlayListItem* s1,PlayListItem* s2)
 {
-    return s1->year().toInt() > s2->year().toInt();
+    return s1->value(Qmmp::YEAR).toInt() > s2->value(Qmmp::YEAR).toInt();
 }
 //by track
 static bool _trackLessComparator(PlayListItem* s1,PlayListItem* s2)
 {
-    return s1->track().toInt() < s2->track().toInt();
+    return s1->value(Qmmp::TRACK).toInt() < s2->value(Qmmp::TRACK).toInt();
 }
 
 static bool _trackGreaterComparator(PlayListItem* s1,PlayListItem* s2)
 {
-    return s1->track().toInt() > s2->track().toInt();
+    return s1->value(Qmmp::TRACK).toInt() > s2->value(Qmmp::TRACK).toInt();
 }
 
 // This is main sort method
@@ -852,24 +814,35 @@ void PlayListModel::doCurrentVisibleRequest()
 void PlayListModel::loadPlaylist(const QString &f_name)
 {
     PlaylistFormat* prs = PlaylistParser::instance()->findByPath(f_name);
-    if (prs)
+    if(!prs)
     {
-        QFile file(f_name);
-        if (file.open(QIODevice::ReadOnly))
-        {
-            //clear();
-            QStringList list = prs->decode(QTextStream(&file).readAll());
-            for (int i = 0; i < list.size(); ++i)
-            {
-                if (QFileInfo(list.at(i)).isRelative() && !list.at(i).contains("://"))
-                    QString path = list[i].prepend(QFileInfo(f_name).canonicalPath () + QDir::separator ());
-            }
-            addFiles(list);
-            file.close();
-        }
-        else
-            qWarning("Error opening %s",f_name.toLocal8Bit().data());
+        qWarning("PlayListModel: unsupported playlist format");
+        return;
     }
+
+    QFile file(f_name);
+    if (!file.open(QIODevice::ReadOnly))
+    {
+        qWarning("PlayListModel: %s", qPrintable(file.errorString()));
+        return;
+    }
+
+    //clear();
+    QStringList list = prs->decode(QTextStream(&file).readAll());
+    if(list.isEmpty())
+    {
+        qWarning("PlayListModel: error opening %s",qPrintable(f_name));
+    }
+    for (int i = 0; i < list.size(); ++i)
+    {
+        if(list.at(i).contains("://"))
+            continue;
+
+        if (QFileInfo(list.at(i)).isRelative())
+            list[i].prepend(QFileInfo(f_name).canonicalPath () + QDir::separator ());
+    }
+    m_loader->loadFiles(list);
+    file.close();
 }
 
 void PlayListModel::savePlaylist(const QString & f_name)
@@ -881,7 +854,7 @@ void PlayListModel::savePlaylist(const QString & f_name)
         if (file.open(QIODevice::WriteOnly))
         {
             QTextStream ts(&file);
-            QList <AbstractPlaylistItem *> songs;
+            QList <PlayListItem *> songs;
             foreach(PlayListItem* item, m_items)
             songs << item;
             ts << prs->encode(songs);
@@ -902,13 +875,9 @@ bool PlayListModel::isShuffle() const
     return m_shuffle;
 }
 
-bool PlayListModel::isFileLoaderRunning() const
+bool PlayListModel::isLoaderRunning() const
 {
-    foreach(FileLoader* l,m_running_loaders)
-    if (l && l->isRunning())
-        return true;
-
-    return false;
+    return m_loader->isRunning();
 }
 
 void PlayListModel::preparePlayState()
@@ -941,3 +910,31 @@ void PlayListModel::removeDuplicates()
         }
     }
 }
+
+void PlayListModel::clearQueue()
+{
+     m_queued_songs.clear();
+     m_stop_item = 0;
+     emit listChanged();
+}
+
+void PlayListModel::stopAfterSelected()
+{
+    QList<PlayListItem*> selected_items = getSelectedItems();
+    if(!m_queued_songs.isEmpty())
+    {
+        m_stop_item = m_stop_item != m_queued_songs.last() ? m_queued_songs.last() : 0;
+    }
+    else if(selected_items.count() == 1)
+    {
+        m_stop_item = m_stop_item != selected_items.at(0) ? selected_items.at(0) : 0;
+    }
+    else if(selected_items.count() > 1)
+    {
+        addToQueue();
+        m_stop_item = m_queued_songs.last();
+    }
+    else
+        return;
+    emit listChanged();
+}
