@@ -24,6 +24,7 @@
 #include <QString>
 #include <QStringList>
 #include <QMap>
+#include <QQueue>
 #include <QPointer>
 #include <QVector>
 #include "playlistitem.h"
@@ -150,6 +151,11 @@ public:
      * @param row Number of item.
      */
     bool setCurrent (int row);
+    /*!
+     * Sets current item to \b item.
+     * Returns \b true if success, otherwise returns \b false
+     */
+    bool setCurrent(PlayListItem *item);
     /*!
      * Returns \b true if \b row is selected, otherwise returns \b false
      */
@@ -175,19 +181,19 @@ public:
      * @param first First item.
      * @param last Last item.
      */
-    QList <QString> getTitles(int first,int last);
+    QStringList getTitles(int first,int last);
     /*!
      * Returns a list of the formated durations.
      * @param first First item.
      * @param last Last item.
      */
-    QList <QString> getTimes(int first,int last);
+    QStringList getTimes(int first,int last);
     /*!
-     *  Moves the item at index position \b from to index position \b to
+     *  Moves the item at index position \b from to index position \b to.
      */
     void moveItems(int from, int to);
     /*!
-     * Returns \b true if \b f file is in play queue, else returns \b false
+     * Returns \b true if \b f file is in play queue, otherwise returns \b false.
      */
     bool isQueued(PlayListItem* item) const;
     /*!
@@ -201,10 +207,15 @@ public:
     /*!
      * Returns index of \b f file in queue.e
      */
-    int queuedIndex(PlayListItem* item) const
-    {
-        return m_queued_songs.indexOf(item);
-    }
+    int queuedIndex(PlayListItem* item) const;
+    /*!
+     * Returns the number of items in the queue
+     */
+    int queueSize() const;
+    /*!
+     * Returns \b true if playback stops after \b item, otherwise returns \b false.
+     */
+    bool isStopAfter(PlayListItem* item) const;
     /*!
      * Returns current selection(playlist can contain a lot of selections,
      * this method returns selection which \b row belongs to)
@@ -256,6 +267,10 @@ public:
      * Returns state of "Shuffle" option.
      */
     bool isShuffle() const;
+    /*!
+     * Returns \b true if the file loader thread is active; otherwise returns \b false.
+     */
+    bool isLoaderRunning() const;
     /*!
      * Returns \b true if the playlist contains an item with URL \b url; otherwise returns \b false.
      */
@@ -284,14 +299,19 @@ signals:
      */
     void currentChanged();
     /*!
-     * Emitted when first item has added.
+     * Emitted when new item has added.
+     * @param item New playlist item pointer.
      */
-    void firstAdded();
+    void itemAdded(PlayListItem *item);
     /*!
      * Emitted when playlist name has chanded.
      * @param name New playlist name.
      */
     void nameChanged(const QString& name);
+    /*!
+     * Emitted when playlist loader thread has finished.
+     */
+    void loaderFinished();
 
 public slots:
     /*!
@@ -300,9 +320,19 @@ public slots:
     void add(PlayListItem *item);
     /*!
      * Adds a list of items to the playlist.
-     * @param items List of items
+     * @param items List of items.
      */
     void add(QList <PlayListItem *> items);
+    /*!
+     * Adds a list of files and directories to the playlist
+     * @param path Full path of file or directory.
+     */
+    void add(const QString &path);
+    /*!
+     * Adds a list of files and directories to the playlist
+     * @param paths Full paths of files and directories.
+     */
+    void add(const QStringList &paths);
     /*!
      * Removes all items.
      */
@@ -337,34 +367,13 @@ public slots:
     void selectAll();
     /*!
      * Shows details for the first selected item.
+     * @param parent parent Widget.
      */
-    void showDetails();
+    void showDetails(QWidget *parent = 0);
     /*!
      * Emits update signals manually.
      */
     void doCurrentVisibleRequest();
-    /*!
-     * Adds file \b path to the playlist. File should be supported.
-     */
-    void addFile(const QString &path);
-    /*!
-     * Adds the list \b l of files to the model.
-     */
-    void addFiles(const QStringList& l);
-    /*!
-     * Adds \b dir to the model.
-     */
-    void addDirectory(const QString& dir);
-    /*!
-     * Removes previous items and loads list of files (regular files or directories),
-     * returns \b true if at least one file has been successfully loaded,
-     * otherwise returns \b false
-     */
-    bool setFileList(const QStringList &l);
-    /*!
-     * Loads list of files (regular files or directories)
-     */
-    void addFileList(const QStringList &l);
     /*!
      * Randomly changes items order.
      */
@@ -405,6 +414,14 @@ public slots:
      * Removes duplicate items by URL.
      */
     void removeDuplicates();
+    /*!
+     * Removes all items from queue.
+     */
+    void clearQueue();
+    /*!
+     * Toggles 'stop after selected' feature.
+     */
+    void stopAfterSelected();
 
 private:
     /*!
@@ -419,14 +436,6 @@ private:
      * Returns bottommost row in current selection
      */
     int bottommostInSelection(int);
-    /*!
-     * Creates and initializes file loader object.
-     */
-    FileLoader* createFileLoader();
-    /*!
-     * Is someone of file loaders is running?
-     */
-    bool isFileLoaderRunning()const;
     /*!
      * Removes items from model. If \b inverted is \b false -
      * selected items will be removed, else - unselected.
@@ -440,6 +449,7 @@ private:
     QList <PlayListItem*> m_items;
     QList <PlayListItem*> m_editing_items;
     PlayListItem* m_currentItem;
+    PlayListItem* m_stop_item;
     int m_current;
     /*!
      * This flyweight object represents current selection.
@@ -448,7 +458,7 @@ private:
     /*!
      * Songs in play queue.
      */
-    QList<PlayListItem*> m_queued_songs;
+    QQueue <PlayListItem*> m_queued_songs;
     /*!
      * Is playlist repeatable?
      */
@@ -458,13 +468,7 @@ private:
      */
     PlayState* m_play_state;
     int m_total_length;
-    typedef QPointer<FileLoader> GuardedFileLoader;
-    /*!
-     * Vector of currently running file loaders.
-     *  All loaders are automatically sheduled for deletion
-     * when finished.
-     */
-    QVector<GuardedFileLoader> m_running_loaders;
+    FileLoader *m_loader;
     bool m_shuffle;
     QString m_name;
 };
