@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2007-2010 by Ilya Kotov                                 *
+ *   Copyright (C) 2007-2011 by Ilya Kotov                                 *
  *   forkotov02@hotmail.ru                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -45,6 +45,9 @@
 #include <qmmpui/filedialog.h>
 #include <qmmpui/mediaplayer.h>
 #include <qmmpui/playlistmodel.h>
+#include "shortcutdialog.h"
+#include "actionmanager.h"
+#include "shortcutitem.h"
 #include "popupsettings.h"
 #include "skin.h"
 #include "pluginitem.h"
@@ -52,7 +55,7 @@
 #include "skinreader.h"
 
 ConfigDialog::ConfigDialog (QWidget *parent)
-        : QDialog (parent)
+    : QDialog (parent)
 {
     ui.setupUi (this);
     setAttribute(Qt::WA_QuitOnClose, false);
@@ -75,8 +78,18 @@ ConfigDialog::ConfigDialog (QWidget *parent)
     m_reader = new SkinReader(this);
     loadSkins();
     loadPluginsInfo();
+    loadShortcuts();
     loadFonts();
-    createMenus();    
+    createMenus();
+    //setup icons
+    ui.skinInstallButton->setIcon(QIcon::fromTheme("list-add"));
+    ui.skinReloadButton->setIcon(QIcon::fromTheme("view-refresh"));
+    ui.popupTemplateButton->setIcon(QIcon::fromTheme("configure"));
+    ui.preferencesButton->setIcon(QIcon::fromTheme("configure"));
+    ui.informationButton->setIcon(QIcon::fromTheme("dialog-information"));
+    ui.fdInformationButton->setIcon(QIcon::fromTheme("dialog-information"));
+    ui.outputInformationButton->setIcon(QIcon::fromTheme("dialog-information"));
+    ui.outputPreferencesButton->setIcon(QIcon::fromTheme("configure"));
 }
 
 ConfigDialog::~ConfigDialog()
@@ -94,6 +107,8 @@ void ConfigDialog::readSettings()
     }
     ui.protocolCheckBox->setChecked(settings.value ("PlayList/show_protocol", false).toBool());
     ui.numbersCheckBox->setChecked(settings.value ("PlayList/show_numbers", true).toBool());
+    ui.alignCheckBox->setChecked(settings.value ("PlayList/align_numbers", false).toBool());
+    ui.anchorCheckBox->setChecked(settings.value("PlayList/show_anchor", false).toBool());
     ui.playlistsCheckBox->setChecked(settings.value("PlayList/show_plalists", false).toBool());
     ui.popupCheckBox->setChecked(settings.value("PlayList/show_popup", false).toBool());
     QmmpSettings *gs = QmmpSettings::instance();
@@ -110,20 +125,15 @@ void ConfigDialog::readSettings()
     ui.portLineEdit->setEnabled(ui.enableProxyCheckBox->isChecked());
     ui.proxyUserLineEdit->setEnabled(ui.authProxyCheckBox->isChecked());
     ui.proxyPasswLineEdit->setEnabled(ui.authProxyCheckBox->isChecked());
-
-    ui.hiddenCheckBox->setChecked(settings.value("MainWindow/start_hidden", false).toBool());
-    ui.hideOnCloseCheckBox->setChecked(settings.value("MainWindow/hide_on_close", false).toBool());
     //transparency
     ui.mwTransparencySlider->setValue(100 - settings.value("MainWindow/opacity", 1.0).toDouble()*100);
     ui.eqTransparencySlider->setValue(100 - settings.value("Equalizer/opacity", 1.0).toDouble()*100);
     ui.plTransparencySlider->setValue(100 - settings.value("PlayList/opacity", 1.0).toDouble()*100);
-    //compatibility
-    ui.openboxCheckBox->setChecked(settings.value("General/openbox_compat", false).toBool());
-    ui.metacityCheckBox->setChecked(settings.value("General/metacity_compat", false).toBool());
     //view
     ui.skinCursorsCheckBox->setChecked(settings.value("General/skin_cursors", false).toBool());
-    ui.doubleSizeCheckBox->setChecked(settings.value("General/double_size", false).toBool());
-    ui.alwaysOnTopCheckBox->setChecked(settings.value("General/always_on_top", false).toBool());
+    m_currentSkinName = settings.value("General/skin_name", "default").toString();
+    ui.hiddenCheckBox->setChecked(settings.value("MainWindow/start_hidden", false).toBool());
+    ui.hideOnCloseCheckBox->setChecked(settings.value("MainWindow/hide_on_close", false).toBool());
     //resume playback
     ui.continuePlaybackCheckBox->setChecked(settings.value("General/resume_on_startup", false).toBool());
     //cover options
@@ -136,9 +146,10 @@ void ConfigDialog::readSettings()
     ui.replayGainModeComboBox->setCurrentIndex(ui.replayGainModeComboBox->findData(gs->replayGainMode()));
     ui.preampDoubleSpinBox->setValue(gs->replayGainPreamp());
     ui.defaultGainDoubleSpinBox->setValue(gs->replayGainDefaultGain());
-     //audio
+    //audio
     ui.softVolumeCheckBox->setChecked(gs->useSoftVolume());
     ui.use16BitCheckBox->setChecked(gs->use16BitOutput());
+    ui.bufferSizeSpinBox->setValue(gs->bufferSize());
 }
 
 void ConfigDialog::on_contentsWidget_currentItemChanged (QListWidgetItem *current,
@@ -147,7 +158,8 @@ void ConfigDialog::on_contentsWidget_currentItemChanged (QListWidgetItem *curren
     if (!current)
         current = previous;
     ui.stackedWidget->setCurrentIndex (ui.contentsWidget->row (current));
-    ui.visibilityGroupBox->setEnabled(GeneralHandler::instance()->visibilityControl());
+    ui.hiddenCheckBox->setEnabled(GeneralHandler::instance()->visibilityControl());
+    ui.hideOnCloseCheckBox->setEnabled(GeneralHandler::instance()->visibilityControl());
 }
 
 void ConfigDialog::changeSkin()
@@ -164,6 +176,10 @@ void ConfigDialog::changeSkin()
         m_reader->unpackSkin(m_skinList.at (row).canonicalFilePath());
         m_skin->setSkin(QDir::homePath() +"/.qmmp/cache/skin");
     }
+    if(ui.listWidget->currentItem())
+        m_currentSkinName = ui.listWidget->currentItem()->text();
+    else
+        m_currentSkinName.clear();
 }
 
 void ConfigDialog::loadSkins()
@@ -177,6 +193,8 @@ void ConfigDialog::loadSkins()
     item->setIcon (preview);
     ui.listWidget->addItem (item);
     m_skinList << fileInfo;
+    if(item->text() == m_currentSkinName)
+        ui.listWidget->setCurrentItem(item);
 
     findSkins(QDir::homePath() +"/.qmmp/skins");
 #ifdef Q_OS_WIN32
@@ -191,6 +209,8 @@ void ConfigDialog::loadSkins()
         item->setToolTip(tr("Archived skin") + " " + path);
         ui.listWidget->addItem (item);
         m_skinList << QFileInfo(path);
+        if(item->text() == m_currentSkinName)
+            ui.listWidget->setCurrentItem(item);
     }
 }
 
@@ -328,6 +348,37 @@ void ConfigDialog::loadFonts()
     ui.useBitmapCheckBox->setChecked(settings.value("MainWindow/bitmap_font", false).toBool());
 }
 
+void ConfigDialog::loadShortcuts()
+{
+    //playback
+    QTreeWidgetItem *item = new QTreeWidgetItem (ui.shortcutTreeWidget, QStringList() << tr("Playback"));
+    for(int i = ActionManager::PLAY; i <= ActionManager::CLEAR_QUEUE; ++i)
+        new ShortcutItem(item, i);
+    item->setExpanded(true);
+    ui.shortcutTreeWidget->addTopLevelItem(item);
+    //view
+    item = new QTreeWidgetItem (ui.shortcutTreeWidget, QStringList() << tr("View"));
+    for(int i = ActionManager::SHOW_PLAYLIST; i <= ActionManager::WM_DOUBLE_SIZE; ++i)
+        new ShortcutItem(item, i);
+    item->setExpanded(true);
+    ui.shortcutTreeWidget->addTopLevelItem(item);
+    //playlist
+    item = new QTreeWidgetItem (ui.shortcutTreeWidget, QStringList() << tr("Playlist"));
+    for(int i = ActionManager::PL_ADD_FILE; i <= ActionManager::PL_SHOW_MANAGER; ++i)
+        new ShortcutItem(item, i);
+    item->setExpanded(true);
+    ui.shortcutTreeWidget->addTopLevelItem(item);
+    //misc
+    item = new QTreeWidgetItem (ui.shortcutTreeWidget, QStringList() << tr("Misc"));
+    for(int i = ActionManager::SETTINGS; i <= ActionManager::QUIT; ++i)
+        new ShortcutItem(item, i);
+    item->setExpanded(true);
+    ui.shortcutTreeWidget->addTopLevelItem(item);
+
+    ui.shortcutTreeWidget->resizeColumnToContents(0);
+    ui.shortcutTreeWidget->resizeColumnToContents(1);
+}
+
 void ConfigDialog::setPlFont()
 {
     bool ok;
@@ -414,6 +465,8 @@ void ConfigDialog::saveSettings()
     }
     settings.setValue ("PlayList/show_protocol", ui.protocolCheckBox->isChecked());
     settings.setValue ("PlayList/show_numbers", ui.numbersCheckBox->isChecked());
+    settings.setValue ("PlayList/align_numbers", ui.alignCheckBox->isChecked());
+    settings.setValue ("PlayList/show_anchor", ui.anchorCheckBox->isChecked());
     settings.setValue ("PlayList/show_plalists", ui.playlistsCheckBox->isChecked());
     settings.setValue ("PlayList/show_popup", ui.popupCheckBox->isChecked());
     FileDialog::setEnabled(FileDialog::registeredFactories().at(ui.fileDialogComboBox->currentIndex()));
@@ -428,18 +481,16 @@ void ConfigDialog::saveSettings()
                            ui.authProxyCheckBox->isChecked(),
                            proxyUrl);
 
-    settings.setValue ("MainWindow/start_hidden", ui.hiddenCheckBox->isChecked());
-    settings.setValue ("MainWindow/hide_on_close", ui.hideOnCloseCheckBox->isChecked());
+
     settings.setValue ("MainWindow/opacity", 1.0 -  (double)ui.mwTransparencySlider->value()/100);
     settings.setValue ("Equalizer/opacity", 1.0 -  (double)ui.eqTransparencySlider->value()/100);
     settings.setValue ("PlayList/opacity", 1.0 -  (double)ui.plTransparencySlider->value()/100);
-    settings.setValue ("General/openbox_compat", ui.openboxCheckBox->isChecked());
-    settings.setValue ("General/metacity_compat", ui.metacityCheckBox->isChecked());
     settings.setValue ("General/resume_on_startup",  ui.continuePlaybackCheckBox->isChecked());
     settings.setValue ("MainWindow/bitmap_font", ui.useBitmapCheckBox->isChecked());
     settings.setValue ("General/skin_cursors", ui.skinCursorsCheckBox->isChecked());
-    settings.setValue ("General/double_size", ui.doubleSizeCheckBox->isChecked());
-    settings.setValue ("General/always_on_top", ui.alwaysOnTopCheckBox->isChecked());
+    settings.setValue ("General/skin_name", m_currentSkinName);
+    settings.setValue ("MainWindow/start_hidden", ui.hiddenCheckBox->isChecked());
+    settings.setValue ("MainWindow/hide_on_close", ui.hideOnCloseCheckBox->isChecked());
     gs->setCoverSettings(ui.coverIncludeLineEdit->text().split(","),
                          ui.coverExcludeLineEdit->text().split(","),
                          ui.coverDepthSpinBox->value(),
@@ -451,6 +502,7 @@ void ConfigDialog::saveSettings()
                               ui.defaultGainDoubleSpinBox->value(),
                               ui.clippingCheckBox->isChecked());
     gs->setAudioSettings(ui.softVolumeCheckBox->isChecked(), ui.use16BitCheckBox->isChecked());
+    gs->setBufferSize(ui.bufferSizeSpinBox->value());
     QList <OutputFactory *> *outputs = Output::factories();
     if(ui.outputComboBox->currentIndex() >= 0 && outputs->count())
         Output::setCurrentFactory(outputs->at(ui.outputComboBox->currentIndex()));
@@ -470,7 +522,7 @@ void ConfigDialog::on_fdInformationButton_clicked()
 void ConfigDialog::installSkin()
 {
     QStringList files = FileDialog::getOpenFileNames(this,tr("Select Skin Files"), QDir::homePath(),
-                        tr("Skin files") + " (*.tar.gz *.tgz *.tar.bz2 *.zip *.wsz)");
+                                                     tr("Skin files") + " (*.tar.gz *.tgz *.tar.bz2 *.zip *.wsz)");
     foreach(QString path, files)
     {
         QFile file(path);
@@ -479,7 +531,7 @@ void ConfigDialog::installSkin()
     loadSkins();
 }
 
-void ConfigDialog::on_popupCustomizeButton_clicked()
+void ConfigDialog::on_popupTemplateButton_clicked()
 {
     PopupSettings *p = new PopupSettings(this);
     p->exec();
@@ -506,21 +558,34 @@ void ConfigDialog::on_treeWidget_currentItemChanged (QTreeWidgetItem *current, Q
     }
 }
 
- void ConfigDialog::on_outputComboBox_activated (int index)
- {
-     OutputFactory *factory = Output::factories()->at(index);
-     ui.outputInformationButton->setEnabled(factory->properties().hasAbout);
-     ui.outputPreferencesButton->setEnabled(factory->properties().hasSettings);
- }
+void ConfigDialog::on_outputComboBox_activated (int index)
+{
+    OutputFactory *factory = Output::factories()->at(index);
+    ui.outputInformationButton->setEnabled(factory->properties().hasAbout);
+    ui.outputPreferencesButton->setEnabled(factory->properties().hasSettings);
+}
 
- void ConfigDialog::on_outputPreferencesButton_clicked()
- {
-     int index = ui.outputComboBox->currentIndex();
-     Output::factories()->at(index)->showSettings(this);
- }
+void ConfigDialog::on_outputPreferencesButton_clicked()
+{
+    int index = ui.outputComboBox->currentIndex();
+    Output::factories()->at(index)->showSettings(this);
+}
 
- void ConfigDialog::on_outputInformationButton_clicked()
- {
-     int index = ui.outputComboBox->currentIndex();
-     Output::factories()->at(index)->showAbout(this);
- }
+void ConfigDialog::on_outputInformationButton_clicked()
+{
+    int index = ui.outputComboBox->currentIndex();
+    Output::factories()->at(index)->showAbout(this);
+}
+
+void ConfigDialog::on_changeShortcutButton_clicked()
+{
+    ShortcutItem *item = dynamic_cast<ShortcutItem *> (ui.shortcutTreeWidget->currentItem());
+    if(!item)
+        return;
+    ShortcutDialog editor(item->action()->shortcut().toString(), this);
+    if(editor.exec() == QDialog::Accepted)
+    {
+        item->action()->setShortcut(editor.key());
+        item->setText(1, item->action()->shortcut().toString());
+    }
+}
