@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2006-2010 by Ilya Kotov                                 *
+ *   Copyright (C) 2006-2011 by Ilya Kotov                                 *
  *   forkotov02@hotmail.ru                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -35,7 +35,6 @@
 #include <qmmpui/playlistmodel.h>
 #include <qmmpui/playlistmanager.h>
 #include <qmmpui/mediaplayer.h>
-#include "textscroller.h"
 #include "mainwindow.h"
 #include "skin.h"
 #include "playlist.h"
@@ -48,6 +47,8 @@
 #include "addurldialog.h"
 #include "listwidget.h"
 #include "visualmenu.h"
+#include "windowsystem.h"
+#include "actionmanager.h"
 #include "builtincommandlineoption.h"
 
 #define KEY_OFFSET 10000
@@ -55,17 +56,19 @@
 MainWindow::MainWindow(const QStringList& args, BuiltinCommandLineOption* option_manager, QWidget *parent)
         : QMainWindow(parent)
 {
+#ifdef Q_WS_X11
+    qDebug("MainWindow: detected wm: %s", qPrintable(WindowSystem::netWindowManagerName()));
+#endif
     m_vis = 0;
     m_update = false;
     m_option_manager = option_manager;
     setWindowIcon(QIcon(":/32x32/qmmp.png"));
-#if QT_VERSION >= 0x040500
-    setWindowFlags(Qt::Window | Qt::FramelessWindowHint | Qt::WindowCloseButtonHint | Qt::WindowSystemMenuHint);
-#else
-    setWindowFlags(Qt::Window | Qt::FramelessWindowHint | Qt::WindowSystemMenuHint);
-#endif
+    setWindowFlags(Qt::Window | Qt::FramelessWindowHint |
+                   Qt::WindowCloseButtonHint | Qt::WindowSystemMenuHint);
     setWindowTitle("Qmmp");
 
+    new ActionManager();
+
     //prepare libqmmp and libqmmpui libraries for playing
     m_player = new MediaPlayer(this);
     m_core = new SoundCore(this);
@@ -111,13 +114,11 @@ MainWindow::MainWindow(const QStringList& args, BuiltinCommandLineOption* option
     connect(m_display,SIGNAL(shuffleToggled(bool)),m_pl_manager,SLOT(setShuffle(bool)));
     connect(m_display,SIGNAL(repeatableToggled(bool)),m_pl_manager,SLOT(setRepeatableList(bool)));
 
-    connect(m_equalizer, SIGNAL(valueChanged()), SLOT(updateEQ()));
     connect(m_jumpDialog,SIGNAL(playRequest()), SLOT(replay()));
 
     connect(m_core, SIGNAL(stateChanged(Qmmp::State)), SLOT(showState(Qmmp::State)));
     connect(m_core, SIGNAL(elapsedChanged(qint64)),m_playlist, SLOT(setTime(qint64)));
     connect(m_core, SIGNAL(metaDataChanged()),SLOT(showMetaData()));
-    connect(m_core, SIGNAL(bufferingProgress(int)), TextScroller::getPointer(), SLOT(setProgress(int)));
     connect(m_generalHandler, SIGNAL(toggleVisibilityCalled()), SLOT(toggleVisibility()));
     connect(m_generalHandler, SIGNAL(exitCalled()), SLOT(close()));
 
@@ -126,7 +127,6 @@ MainWindow::MainWindow(const QStringList& args, BuiltinCommandLineOption* option
     m_display->setPL(m_playlist);
     dock->updateDock();
     m_pl_manager->currentPlayList()->doCurrentVisibleRequest();
-    updateEQ();
 #ifndef Q_OS_WIN32
     QString cwd = QDir::currentPath();
     processCommandArgs(args,cwd);
@@ -137,7 +137,6 @@ MainWindow::MainWindow(const QStringList& args, BuiltinCommandLineOption* option
         resume();
 }
 
-
 MainWindow::~MainWindow()
 {}
 
@@ -153,19 +152,14 @@ void MainWindow::replay()
     play();
 }
 
-void MainWindow::seek(qint64 pos)
-{
-    m_core->seek(pos);
-}
-
 void MainWindow::forward()
 {
-    seek(m_core->elapsed() + KEY_OFFSET);
+    m_core->seek(m_core->elapsed() + KEY_OFFSET);
 }
 
 void MainWindow::backward()
 {
-    seek(qMax(qint64(0), m_core->elapsed() - KEY_OFFSET));
+    m_core->seek(qMax(qint64(0), m_core->elapsed() - KEY_OFFSET));
 }
 
 void MainWindow::setVolume(int volume, int balance)
@@ -194,29 +188,14 @@ void MainWindow::previous()
     m_player->previous();
 }
 
-void MainWindow::updateEQ()
-{
-    double b[10];
-    for (int i=0; i<10; ++i)
-        b[i] = m_equalizer->gain(i);
-    m_core->setEQ(b, m_equalizer->preamp());
-    m_core->setEQEnabled(m_equalizer->isEQEnabled());
-}
-
 void MainWindow::showState(Qmmp::State state)
 {
-    if(m_model)
-    {
-        disconnect(m_model, SIGNAL(firstAdded()), this, 0);
-        m_model = 0;
-    }
+    disconnectPl();
     switch ((int) state)
     {
     case Qmmp::Playing:
         if (m_pl_manager->currentPlayList()->currentItem())
             m_equalizer->loadPreset(m_pl_manager->currentPlayList()->currentItem()->url().section("/",-1));
-        if (m_playlist->listWidget())
-            m_playlist->listWidget()->updateList(); //removes progress message from TextScroller
         break;
     case Qmmp::Paused:
         break;
@@ -247,7 +226,6 @@ void MainWindow::showMetaData()
     {
         m_playlist->currentItem()->updateMetaData(m_core->metaData());
         m_playlist->updateList();
-        TextScroller::getPointer()->setText(m_playlist->currentItem()->text());
         setWindowTitle(m_playlist->currentItem()->text());
     }
 }
@@ -263,7 +241,7 @@ void MainWindow::closeEvent (QCloseEvent *)
 void MainWindow::addDir()
 {
     FileDialog::popup(this, FileDialog::AddDirs, &m_lastDir,
-                      m_pl_manager->selectedPlayList(), SLOT(addFileList(const QStringList&)),
+                      m_pl_manager->selectedPlayList(), SLOT(add(const QStringList&)),
                       tr("Choose a directory"));
 }
 
@@ -274,7 +252,7 @@ void MainWindow::addFile()
             MetaDataManager::instance()->nameFilters().join (" ") +")";
     filters << MetaDataManager::instance()->filters();
     FileDialog::popup(this, FileDialog::AddDirsFiles, &m_lastDir,
-                      m_pl_manager->selectedPlayList(), SLOT(addFileList(const QStringList&)),
+                      m_pl_manager->selectedPlayList(), SLOT(add(const QStringList&)),
                       tr("Select one or more files to open"), filters.join(";;"));
 }
 
@@ -298,13 +276,21 @@ void MainWindow::readSettings()
         m_lastDir = settings.value("last_dir","/").toString(); //last directory
         m_startHidden = settings.value("start_hidden", false).toBool();
         settings.endGroup();
+
         if(settings.value("General/always_on_top", false).toBool())
+        {
+            ACTION(ActionManager::WM_ALLWAYS_ON_TOP)->setChecked(true);
             setWindowFlags(windowFlags() | Qt::WindowStaysOnTopHint);
+        }
+        ACTION(ActionManager::WM_STICKY)->setChecked(settings.value("General/show_on_all_desktops",
+                                                                    false).toBool());
         show();
         qApp->processEvents();
         //visibility
         m_playlist->setVisible(settings.value("Playlist/visible",true).toBool());
+        qApp->processEvents();
         m_equalizer->setVisible(settings.value("Equalizer/visible",true).toBool());
+        qApp->processEvents();
         bool val = settings.value("Playlist/repeatable",false).toBool();
 
         // Repeat/Shuffle
@@ -318,7 +304,7 @@ void MainWindow::readSettings()
     }
     else
     {
-        if(settings.value("General/always_on_top", false).toBool())
+        if(ACTION(ActionManager::WM_ALLWAYS_ON_TOP)->isChecked())
         {
             setWindowFlags(windowFlags() | Qt::WindowStaysOnTopHint);
             m_playlist->setWindowFlags(m_playlist->windowFlags() | Qt::WindowStaysOnTopHint);
@@ -331,16 +317,27 @@ void MainWindow::readSettings()
             m_equalizer->setWindowFlags(m_equalizer->windowFlags() & ~Qt::WindowStaysOnTopHint);
         }
         show();
+        qApp->processEvents();
         m_playlist->setVisible(m_display->isPlaylistVisible());
         m_equalizer->setVisible(m_display->isEqualizerVisible());
     }
+#ifdef Q_WS_X11
+    WindowSystem::changeWinSticky(winId(), ACTION(ActionManager::WM_STICKY)->isChecked());
+    WindowSystem::setWinHint(winId(), "player", "Qmmp");
+#endif
+    //Call setWindowOpacity only if needed
+    double opacity = settings.value("MainWindow/opacity", 1.0).toDouble();
+    if(opacity != windowOpacity ())
+        setWindowOpacity(opacity);
+
+    opacity = settings.value("Equalizer/opacity", 1.0).toDouble();
+    if(opacity !=  m_equalizer->windowOpacity ())
+        m_equalizer->setWindowOpacity(opacity);
+
+    opacity = settings.value("PlayList/opacity", 1.0).toDouble();
+    if(opacity !=  m_playlist->windowOpacity ())
+        m_playlist->setWindowOpacity(opacity);
 
-    if(!settings.value("General/metacity_compat", false).toBool())
-    {
-        setWindowOpacity(settings.value("MainWindow/opacity", 1.0).toDouble());
-        m_equalizer->setWindowOpacity(settings.value("Equalizer/opacity", 1.0).toDouble());
-        m_playlist->setWindowOpacity(settings.value("PlayList/opacity", 1.0).toDouble());
-    }
     m_hideOnClose = settings.value("MainWindow/hide_on_close", false).toBool();
 }
 
@@ -363,6 +360,9 @@ void MainWindow::writeSettings()
     settings.setValue("resume_playback", m_core->state() == Qmmp::Playing &&
                       settings.value("resume_on_startup", false).toBool());
     settings.setValue("resume_playback_time", m_core->totalTime() > 0 ? m_core->elapsed() : 0);
+    settings.setValue("double_size", ACTION(ActionManager::WM_DOUBLE_SIZE)->isChecked());
+    settings.setValue("always_on_top", ACTION(ActionManager::WM_ALLWAYS_ON_TOP)->isChecked());
+    settings.setValue("show_on_all_desktops", ACTION(ActionManager::WM_STICKY)->isChecked());
     settings.endGroup();
 }
 
@@ -370,13 +370,9 @@ void MainWindow::showSettings()
 {
     ConfigDialog *confDialog = new ConfigDialog(this);
     confDialog->exec();
-    readSettings();
-    m_playlist->readSettings();
-    TextScroller::getPointer()->readSettings();
-    m_visMenu->updateActions();
-    m_skin->reloadSkin();
-    Dock::instance()->updateDock();
+    updateSettings();
     confDialog->deleteLater();
+    ActionManager::instance()->saveActions();
 }
 
 void MainWindow::toggleVisibility()
@@ -388,6 +384,13 @@ void MainWindow::toggleVisibility()
         activateWindow();
         m_playlist->setVisible(m_display->isPlaylistVisible());
         m_equalizer->setVisible(m_display->isEqualizerVisible());
+#ifdef Q_WS_X11
+        if(WindowSystem::netWindowManagerName() == "Metacity")
+        {
+            m_playlist->activateWindow();
+            m_equalizer->activateWindow();
+        }
+#endif
         qApp->processEvents();
         setFocus ();
         if (isMinimized())
@@ -397,6 +400,11 @@ void MainWindow::toggleVisibility()
             else
                 showNormal();
         }
+#ifdef Q_WS_X11
+        WindowSystem::changeWinSticky(winId(), ACTION(ActionManager::WM_STICKY)->isChecked());
+        WindowSystem::setWinHint(winId(), "player", "Qmmp");
+        raise();
+#endif
     }
     else
     {
@@ -412,42 +420,52 @@ void MainWindow::toggleVisibility()
 void MainWindow::createActions()
 {
     m_mainMenu = new QMenu(this);
-    m_mainMenu->addAction(tr("&Play"),this, SLOT(play()), tr("X"));
-    m_mainMenu->addAction(tr("&Pause"),m_core, SLOT(pause()), tr("C"));
-    m_mainMenu->addAction(tr("&Stop"),this, SLOT(stop()), tr("V"));
-    m_mainMenu->addAction(tr("&Previous"),this, SLOT(previous()), tr("Z"));
-    m_mainMenu->addAction(tr("&Next"),this, SLOT(next()), tr("B"));
-    m_mainMenu->addAction(tr("&Play/Pause"),this, SLOT(playPause()), tr("Space"));
+    m_mainMenu->addAction(SET_ACTION(ActionManager::PLAY, this, SLOT(play())));
+    m_mainMenu->addAction(SET_ACTION(ActionManager::PAUSE, this, SLOT(pause())));
+    m_mainMenu->addAction(SET_ACTION(ActionManager::STOP, this, SLOT(stop())));
+    m_mainMenu->addAction(SET_ACTION(ActionManager::PREVIOUS, this, SLOT(previous())));
+    m_mainMenu->addAction(SET_ACTION(ActionManager::NEXT, this, SLOT(next())));
+    m_mainMenu->addAction(SET_ACTION(ActionManager::PLAY_PAUSE, this, SLOT(playPause())));
     m_mainMenu->addSeparator();
-    QAction *repeateAllAction = m_mainMenu->addAction(tr("&Repeat Playlist"));
-    QAction *repeateTrackAction = m_mainMenu->addAction(tr("&Repeat Track"));
-    QAction *shuffleAction = m_mainMenu->addAction(tr("&Shuffle"));
-    repeateAllAction->setCheckable (true);
-    repeateTrackAction->setCheckable (true);
-    shuffleAction->setCheckable (true);
-    repeateAllAction->setShortcut(tr("R")) ;
-    repeateTrackAction->setShortcut(tr("Ctrl+R")) ;
-    shuffleAction->setShortcut(tr("S")) ;
-    connect(repeateAllAction, SIGNAL(triggered (bool)), m_pl_manager, SLOT(setRepeatableList(bool)));
-    connect(repeateTrackAction, SIGNAL(triggered (bool)), m_player, SLOT(setRepeatable(bool)));
-    connect(shuffleAction, SIGNAL(triggered (bool)), m_pl_manager, SLOT(setShuffle(bool)));
-    connect(m_pl_manager, SIGNAL(repeatableListChanged(bool)), repeateAllAction, SLOT(setChecked(bool)));
-    connect(m_player, SIGNAL (repeatableChanged(bool)), repeateTrackAction, SLOT(setChecked(bool)));
-    connect(m_pl_manager, SIGNAL(shuffleChanged(bool)), shuffleAction, SLOT(setChecked(bool)));
-    m_mainMenu->addSeparator();
-    m_mainMenu->addAction(tr("&Jump To File"),this, SLOT(jumpToFile()), tr("J"));
+    m_mainMenu->addAction(QIcon::fromTheme("go-up"), tr("&Jump To File"),
+                          this, SLOT(jumpToFile()), tr("J"));
     m_mainMenu->addSeparator();
+    QMenu *viewMenu = m_mainMenu->addMenu(tr("View"));
+    viewMenu->addAction(ACTION(ActionManager::SHOW_PLAYLIST));
+    viewMenu->addAction(ACTION(ActionManager::SHOW_EQUALIZER));
+    viewMenu->addSeparator();
+    viewMenu->addAction(SET_ACTION(ActionManager::WM_ALLWAYS_ON_TOP, this, SLOT(updateSettings())));
+    viewMenu->addAction(SET_ACTION(ActionManager::WM_STICKY, this, SLOT(updateSettings())));
+    viewMenu->addAction(SET_ACTION(ActionManager::WM_DOUBLE_SIZE, this, SLOT(updateSettings())));
+
+    QMenu *plMenu = m_mainMenu->addMenu(tr("Playlist"));
+    plMenu->addAction(SET_ACTION(ActionManager::REPEAT_ALL, m_pl_manager, SLOT(setRepeatableList(bool))));
+    plMenu->addAction(SET_ACTION(ActionManager::REPEAT_TRACK, m_player, SLOT(setRepeatable(bool))));
+    plMenu->addAction(SET_ACTION(ActionManager::SHUFFLE, m_pl_manager, SLOT(setShuffle(bool))));
+    plMenu->addAction(SET_ACTION(ActionManager::NO_PL_ADVANCE, m_player,
+                                 SLOT(setNoPlaylistAdvance(bool))));
+    plMenu->addAction(SET_ACTION(ActionManager::STOP_AFTER_SELECTED, m_pl_manager,
+                                 SLOT(stopAfterSelected())));
+    plMenu->addAction(SET_ACTION(ActionManager::CLEAR_QUEUE, m_pl_manager, SLOT(clearQueue())));
+    connect(m_pl_manager, SIGNAL(repeatableListChanged(bool)),
+            ACTION(ActionManager::REPEAT_ALL), SLOT(setChecked(bool)));
+    connect(m_player, SIGNAL (repeatableChanged(bool)),
+            ACTION(ActionManager::REPEAT_TRACK), SLOT(setChecked(bool)));
+    connect(m_player, SIGNAL (noPlaylistAdvanceChanged(bool)),
+            ACTION(ActionManager::NO_PL_ADVANCE), SLOT(setChecked(bool)));
+    connect(m_pl_manager, SIGNAL(shuffleChanged(bool)),
+            ACTION(ActionManager::SHUFFLE), SLOT(setChecked(bool)));
+
     m_visMenu = new VisualMenu(this);
     m_mainMenu->addMenu(m_visMenu);
     m_mainMenu->addMenu(m_generalHandler->createMenu(GeneralHandler::TOOLS_MENU, tr("Tools"), this));
     m_mainMenu->addSeparator();
-    m_mainMenu->addAction(tr("&Settings"), this, SLOT(showSettings()), tr("Ctrl+P"));
+    m_mainMenu->addAction(SET_ACTION(ActionManager::SETTINGS, this, SLOT(showSettings())));
     m_mainMenu->addSeparator();
-    m_mainMenu->addAction(tr("&About"), this, SLOT(about()));
-    m_mainMenu->addAction(tr("&About Qt"), qApp, SLOT(aboutQt()));
-    Dock::instance()->addActions(m_mainMenu->actions());
+    m_mainMenu->addAction(SET_ACTION(ActionManager::ABOUT, this, SLOT(about())));
+    m_mainMenu->addAction(SET_ACTION(ActionManager::ABOUT_QT, qApp, SLOT(aboutQt())));
     m_mainMenu->addSeparator();
-    m_mainMenu->addAction(tr("&Exit"),this, SLOT(close ()), tr("Ctrl+Q"));
+    m_mainMenu->addAction(SET_ACTION(ActionManager::QUIT, this, SLOT(close())));
 
     QAction* forward = new QAction(this);
     forward->setShortcut(QKeySequence(Qt::Key_Right));
@@ -456,7 +474,7 @@ void MainWindow::createActions()
     backward->setShortcut(QKeySequence(Qt::Key_Left));
     connect(backward,SIGNAL(triggered(bool)),this,SLOT(backward()));
 
-    Dock::instance()->addActions( QList<QAction*>() << forward << backward );
+    Dock::instance()->addActions(QList<QAction*>() << forward << backward);
     Dock::instance()->addActions(m_mainMenu->actions());
 }
 
@@ -467,6 +485,15 @@ void MainWindow::about()
     dlg.exec();
 }
 
+void MainWindow::updateSettings()
+{
+    readSettings();
+    m_playlist->readSettings();
+    m_visMenu->updateActions();
+    m_skin->reloadSkin();
+    Dock::instance()->updateDock();
+}
+
 QMenu* MainWindow::menu()
 {
     return m_mainMenu;
@@ -521,22 +548,24 @@ void MainWindow::savePlaylist()
         qWarning("Error: There is no registered playlist parsers");
 }
 
-void MainWindow::setFileList(const QStringList & l)
+void MainWindow::setFileList(const QStringList &l, bool clear)
 {
-    if (m_core->state() == Qmmp::Playing || m_core->state() == Qmmp::Paused)
+    m_pl_manager->activatePlayList(m_pl_manager->selectedPlayList());
+    if(!clear)
+    {
+        m_pl_manager->selectedPlayList()->add(l);
+        return;
+    }
+    if (m_core->state() != Qmmp::Stopped)
     {
         stop();
         qApp->processEvents(); //receive stop signal
     }
-    m_pl_manager->activatePlayList(m_pl_manager->selectedPlayList());
-    connect(m_pl_manager->selectedPlayList(), SIGNAL(firstAdded()), this, SLOT(play()));
-    if (m_pl_manager->selectedPlayList()->setFileList(l))
-        m_model = m_pl_manager->selectedPlayList();
-    else
-    {
-        disconnect(m_pl_manager->selectedPlayList(), SIGNAL(firstAdded()), this, SLOT(play()));
-        addFile();
-    }
+    m_model = m_pl_manager->selectedPlayList();
+    m_model->clear();
+    connect(m_model, SIGNAL(itemAdded(PlayListItem*)), SLOT(play()));
+    connect(m_model, SIGNAL(loaderFinished()), SLOT(disconnectPl()));
+    m_model->add(l);
 }
 
 void MainWindow::playPause()
@@ -547,59 +576,37 @@ void MainWindow::playPause()
         play();
 }
 
-bool MainWindow::processCommandArgs(const QStringList &slist, const QString& cwd)
+QString MainWindow::processCommandArgs(const QStringList &slist, const QString& cwd)
 {
     if(slist.isEmpty())
-        return true;
+        return QString();
     QStringList paths;
-    foreach(QString arg, slist)
+    foreach(QString arg, slist) //detect file/directory paths
     {
         if(arg.startsWith("-"))
             break;
-        else
-            paths.append(arg);
+        paths.append(arg);
     }
     if(!paths.isEmpty())
     {
-        QStringList full_path_list;
-        foreach(QString s, paths)
-        {
-            if ((s.startsWith("/")) || (s.contains("://")))   //is it absolute path or url?
-                full_path_list << s;
-            else
-                full_path_list << cwd + "/" + s;
-        }
-        setFileList(full_path_list);
-        return true;
+        m_option_manager->executeCommand(QString(), paths, cwd, this); //add paths only
+        return QString();
     }
     QHash<QString, QStringList> commands = m_option_manager->splitArgs(slist);
     if(commands.isEmpty())
-        return false;
+        return QString();
     foreach(QString key, commands.keys())
     {
-        if(key == "--enqueue" || key == "-e")
-        {
-            QStringList args = commands.value(key);
-            if(args.isEmpty())
-                return false;
-            QStringList full_path_list;
-            foreach(QString s, args)
-            {
-                if ((s.startsWith("/")) || (s.contains("://")))   //is it absolute path or url?
-                    full_path_list << s;
-                else
-                    full_path_list << cwd + "/" + s;
-            }
-            m_pl_manager->currentPlayList()->addFileList(full_path_list);
-        }
-        else if (CommandLineManager::hasOption(key))
-            m_generalHandler->executeCommand(key, commands.value(key));
+        if(key == "--no-start")
+            continue;
+        if (CommandLineManager::hasOption(key))
+            return CommandLineManager::executeCommand(key, commands.value(key));
         else if (m_option_manager->identify(key))
-            m_option_manager->executeCommand(key, commands.value(key), this);
+            m_option_manager->executeCommand(key, commands.value(key), cwd, this);
         else
-            return false;
+            return QString();
     }
-    return true;
+    return QString();
 }
 
 void MainWindow::jumpToFile()
@@ -619,6 +626,16 @@ void MainWindow::handleCloseRequest()
         QApplication::closeAllWindows();
 }
 
+void MainWindow::disconnectPl()
+{
+    if(m_model)
+    {
+        disconnect(m_model, SIGNAL(itemAdded(PlayListItem*)), this, SLOT(play()));
+        disconnect(m_model, SIGNAL(loaderFinished()), this, SLOT(disconnectPl()));
+        m_model = 0;
+    }
+}
+
 void MainWindow::addUrl()
 {
     AddUrlDialog::popup(this, m_pl_manager->selectedPlayList());
