@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2006 by Ilya Kotov                                      *
+ *   Copyright (C) 2006-2009 by Ilya Kotov                                 *
  *   forkotov02@hotmail.ru                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -28,15 +28,15 @@
 PlayListSlider::PlayListSlider(QWidget *parent)
         : QWidget(parent)
 {
-    m_skin = Skin::getPointer();
-
-    m_moving = FALSE;
-    m_pressed = FALSE;
+    m_skin = Skin::instance();
+    m_moving = false;
+    m_pressed = false;
     m_min = 0;
     m_max = 0;
     m_value = 0;
     pos = 0;
     connect(m_skin, SIGNAL(skinChanged()), this, SLOT(updateSkin()));
+    setCursor(m_skin->getCursor(Skin::CUR_PVSCROLL));
 }
 
 
@@ -56,26 +56,25 @@ void PlayListSlider::paintEvent(QPaintEvent *)
         paint.drawPixmap(0,58+i*29,m_skin->getPlPart(Skin::PL_RFILL));
     }
     if (m_pressed)
-        paint.drawPixmap(5,p,m_skin->getButton(Skin::PL_BT_SCROLL_P));
+        paint.drawPixmap(5*m_skin->ratio(),p,m_skin->getButton(Skin::PL_BT_SCROLL_P));
     else
-        paint.drawPixmap(5,p,m_skin->getButton(Skin::PL_BT_SCROLL_N));
+        paint.drawPixmap(5*m_skin->ratio(),p,m_skin->getButton(Skin::PL_BT_SCROLL_N));
     m_pos = p;
 }
 
 void PlayListSlider::mousePressEvent(QMouseEvent *e)
 {
-
-    m_moving = TRUE;
-    m_pressed = TRUE;
+    m_moving = true;
+    m_pressed = true;
     press_pos = e->y();
-    if (m_pos<e->y() && e->y()<m_pos+18)
+    if (m_pos<e->y() && e->y()<m_pos+18*m_skin->ratio())
     {
         press_pos = e->y()-m_pos;
     }
     else
     {
-        m_value = convert(qMax(qMin(height()-18,e->y()-9),0));
-        press_pos = 9;
+        m_value = convert(qMax(qMin(height()-18*m_skin->ratio(),e->y()-9*m_skin->ratio()),0));
+        press_pos = 9*m_skin->ratio();
         if (m_value!=m_old)
         {
             emit sliderMoved(m_value);
@@ -88,8 +87,8 @@ void PlayListSlider::mousePressEvent(QMouseEvent *e)
 
 void PlayListSlider::mouseReleaseEvent(QMouseEvent*)
 {
-    m_moving = FALSE;
-    m_pressed = FALSE;
+    m_moving = false;
+    m_pressed = false;
     update();
 }
 
@@ -100,7 +99,7 @@ void PlayListSlider::mouseMoveEvent(QMouseEvent* e)
         int po = e->y();
         po = po - press_pos;
 
-        if (0<=po && po<=height()-18)
+        if (0<=po && po<=height()-18*m_skin->ratio())
         {
             m_value = convert(po);
             update();
@@ -126,10 +125,11 @@ void PlayListSlider::setPos(int p, int max)
 void PlayListSlider::updateSkin()
 {
     update();
+    setCursor(m_skin->getCursor(Skin::CUR_PVSCROLL));
 }
 
 int PlayListSlider::convert(int p)
 {
-    return int(floor(double(m_max-m_min)*(p)/(height()-18)+m_min));
+    return int(floor(double(m_max-m_min)*(p)/(height()-18*m_skin->ratio())+m_min));
 }
 
